<?php
/**
 * NFT_Marketplace_Core
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Ajax;

use NFT_Marketplace_Core\Engine\Base;
use NFT_Marketplace_Core\Internals\Helpers\Helper;

/**
 * AJAX in the public
 */
class Ajax extends Base {

	/**
	 * Initialize the class.
	 *
	 * @return void|bool
	 */
	public function initialize() {
		if ( !\apply_filters( 'nft_marketplace_core_nft_marketplace_core_ajax_initialize', true ) ) {
			return;
		}

        // Logged-in user only
        add_action( 'wp_ajax_nft_marketplace_core_love_post', [$this, 'nft_marketplace_core_love_post']);
        add_action( 'wp_ajax_nopriv_nft_marketplace_core_love_post', [$this, 'nft_marketplace_core_love_post']);
    }



    /*
     * Love/Unlove a post
     * Hooked into wp_ajax_ above to save post IDs when button clicked.
     */
    function nft_marketplace_core_love_post() {
        // Security measures for the ajax call
        $nonce = $_POST['_wpnonce'];
        if (!wp_verify_nonce($nonce, 'ajax-nonce'))
            die("Security check has not passed.");
        if (isset($_POST['nft_marketplace_core_love_post'])) {
            $post_id = $_POST['post_id'];
            // Get the count of loves for the particular post
            $post_mt_love_count = get_post_meta($post_id, "nft_marketplace_core_love_count", true);
            if (is_user_logged_in()) {
                $user_id = get_current_user_id();
                // Get the users who loved the post
                $postmetadata_userIDs = get_post_meta($post_id, "nft_marketplace_core_user_loved");
                $users_loved =[];
                if (count($postmetadata_userIDs) != 0) {
                    $users_loved = $postmetadata_userIDs[0];
                }
                if (!is_array($users_loved))
                    $users_loved =[];
                $users_loved['User_ID-' . $user_id] = $user_id;
                if (!Helper::isAlreadyLoved($post_id)) {
                    // Love
                    update_post_meta($post_id, "nft_marketplace_core_user_loved", $users_loved);
                    update_post_meta($post_id, "nft_marketplace_core_love_count", ++$post_mt_love_count);
                    $response['count']   = $post_mt_love_count;
                    $response['message'] = '<i class="fa fa-heart"></i>';
                } else {
                    // Unlove
                    $uid_key = array_search($user_id, $users_loved); // find the key
                    unset($users_loved[$uid_key]); // remove from array
                    update_post_meta($post_id, "nft_marketplace_core_user_loved", $users_loved); // Remove user ID from post meta
                    update_post_meta($post_id, "nft_marketplace_core_love_count", --$post_mt_love_count); // -1 count post meta
                    $response['count']   = $post_mt_love_count;
                    $response['message'] = '<i class="fa fa-heart-o"></i>';
                }
            } elseif(!is_user_logged_in()) {
                $response['count']   = $post_mt_love_count;
                $response['message'] = '<i class="fa fa-heart-o"></i><span class="mtkb-knowledgebase-nolike">'.esc_html__('You have to login or register to like posts!', NFT_MARKETPLACE_CORE_TEXTDOMAIN).'</span>';
            }
            wp_send_json($response);
        }
    }

}
