<?php

/**
 * NFT_Marketplace_Core
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Backend;

// WPBPGen{{#if libraries_inpsyde__assets}}
use Inpsyde\Assets\Asset;
use Inpsyde\Assets\AssetManager;
use Inpsyde\Assets\Script;
use Inpsyde\Assets\Style;
// {{/if}}
use NFT_Marketplace_Core\Engine\Base;

/**
 * This class contain the Enqueue stuff for the backend
 */
class Enqueue extends Base {

	/**
	 * Initialize the class.
	 *
	 * @return void|bool
	 */
	public function initialize() {
		if ( !parent::initialize() ) {
			return;
		}

		// WPBPGen{{#if libraries_inpsyde__assets}}
		\add_action( AssetManager::ACTION_SETUP, array( $this, 'enqueue_assets' ) );
		// {{/if}}
        \add_filter('script_loader_tag', [$this, 'addTypeAttribute'], 10, 3);

    }
	// WPBPGen{{#if libraries_inpsyde__assets}}

	/**
	 * Enqueue assets with Inpyside library https://inpsyde.github.io/assets
	 *
	 * @param \Inpsyde\Assets\AssetManager $asset_manager The class.
	 * @return void
	 */
	public function enqueue_assets( AssetManager $asset_manager ) {
		// Load admin style sheet and JavaScript.
		// WPBPGen{{#if admin-assets_admin-page && admin-assets_settings-css && admin-assets_admin-css}}
		$assets = $this->enqueue_admin_styles();

		if ( !empty( $assets ) ) {
			foreach ( $assets as $asset ) {
				$asset_manager->register( $asset );
			}
		}

		// {{/if}}
		// WPBPGen{{#if admin-assets_admin-page && admin-assets_settings-js && admin-assets_admin-js}}
		$assets = $this->enqueue_admin_scripts();

		if ( !empty( $assets ) ) {
			foreach ( $assets as $asset ) {
				$asset_manager->register( $asset );
			}
		}

		// {{/if}}
	}
	// {{/if}}

	// WPBPGen{{#if admin-assets_admin-page && admin-assets_settings-css && admin-assets_admin-css}}
	/**
	 * Register and enqueue admin-specific style sheet.
	 *
	 * @since 2.0.0
	 * @return array
	 */
	public function enqueue_admin_styles() {
		$admin_page = \get_current_screen();
		$styles     = array();

//		// WPBPGen{{#if libraries_inpsyde__assets}}
//		// WPBPGen{{#if admin-assets_settings-css && libraries_inpsyde__assets}}
//		if ( !\is_null( $admin_page ) && 'toplevel_page_nft-marketplace-core' === $admin_page->id ) {
//			$styles[0] = new Style( NFT_MARKETPLACE_CORE_TEXTDOMAIN . '-settings-style', \plugins_url( 'assets/build/plugin-settings.css', NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION ) );
//			$styles[0]
//				->forLocation( Asset::BACKEND )
//				->withVersion( NFT_MARKETPLACE_CORE_VERSION );
//			$styles[0]->withDependencies( 'dashicons' );
//		}
//
//		// {{/if}}
//		// WPBPGen{{#if admin-assets_admin-css && libraries_inpsyde__assets}}
//		$styles[1] = new Style( NFT_MARKETPLACE_CORE_TEXTDOMAIN . '-admin-style', \plugins_url( 'assets/build/plugin-admin.css', NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION ) );
//		$styles[1]
//			->forLocation( Asset::BACKEND )
//			->withVersion( NFT_MARKETPLACE_CORE_VERSION );
//		$styles[1]->withDependencies( 'dashicons' );
//		// {{/if}}
//		// {{/if}}
		wp_enqueue_style( NFT_MARKETPLACE_CORE_NAME."-alerts", plugin_dir_url( dirname(__FILE__) ) . 'assets/css/nft-marketplace-core-alerts.css', array(), NFT_MARKETPLACE_CORE_VERSION, 'all' );
		wp_enqueue_style(NFT_MARKETPLACE_CORE_NAME, plugin_dir_url(__FILE__) . 'assets/css/nft-marketplace-core-admin.css', array(), NFT_MARKETPLACE_CORE_VERSION, 'all');
		wp_enqueue_style(NFT_MARKETPLACE_CORE_NAME, plugin_dir_url(__FILE__) . 'assets/css/nft-marketplace-core-panel.css', array(), NFT_MARKETPLACE_CORE_VERSION, 'all');
        wp_enqueue_style( NFT_MARKETPLACE_CORE_TEXTDOMAIN, plugin_dir_url( __DIR__ ) . 'assets/css/nft-marketplace-core-loader.css',[], NFT_MARKETPLACE_CORE_VERSION, 'all' );

		return $styles;
	}

	// {{/if}}
	// WPBPGen{{#if admin-assets_admin-page && admin-assets_settings-js && admin-assets_admin-js}}
	/**
	 * Register and enqueue admin-specific JavaScript.
	 *
	 * @since 2.0.0
	 * @return array
	 */
	public function enqueue_admin_scripts() {
		$admin_page = \get_current_screen();
		$scripts    = array();
		// WPBPGen{{#if libraries_inpsyde__assets}}
		// WPBPGen{{#if admin-assets_settings-js && libraries_inpsyde__assets}}

//		if ( !\is_null( $admin_page ) && 'toplevel_page_nft-marketplace-core' === $admin_page->id ) {
//			$scripts[0] = new Script( NFT_MARKETPLACE_CORE_TEXTDOMAIN . '-settings-script', \plugins_url( 'assets/build/plugin-settings.js', NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION ) );
//			$scripts[0]
//				->forLocation( Asset::BACKEND )
//				->withVersion( NFT_MARKETPLACE_CORE_VERSION );
//			$scripts[0]->withDependencies( 'jquery-ui-tabs' );
//			$scripts[0]->canEnqueue(
//				function() {
//					return \current_user_can( 'manage_options' );
//				}
//			);
//		}

		// {{/if}}
		// WPBPGen{{#if admin-assets_admin-js && libraries_inpsyde__assets}}
//		$scripts[1] = new Script( NFT_MARKETPLACE_CORE_TEXTDOMAIN . '-settings-admin', \plugins_url( 'assets/build/plugin-admin.js', NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION ) );
//		$scripts[1]
//			->forLocation( Asset::BACKEND )
//			->withVersion( NFT_MARKETPLACE_CORE_VERSION );
//		$scripts[1]->dependencies();




		wp_enqueue_script(NFT_MARKETPLACE_CORE_NAME, plugin_dir_url(__FILE__) . 'assets/js/nft-marketplace-core-admin.js', array('jquery'), NFT_MARKETPLACE_CORE_VERSION, false);

//		wp_enqueue_script( NFT_MARKETPLACE_CORE_NAME."-market", plugin_dir_url( dirname(__FILE__) ) . 'assets/js/blockchain-interaction/assets/nft-marketplace-core-market.js', array( 'wp-i18n' ), NFT_MARKETPLACE_CORE_VERSION, true );
//		wp_localize_script(NFT_MARKETPLACE_CORE_NAME."-market", 'nftMarketplaceCorelocation', array(
//			'location' => plugin_dir_url(dirname(__FILE__))."assets/",
//		));
//
//		wp_set_script_translations( NFT_MARKETPLACE_CORE_NAME."-market", NFT_MARKETPLACE_CORE_TEXTDOMAIN );


        $scripts[0] = new Script(NFT_MARKETPLACE_CORE_TEXTDOMAIN . "-market", plugin_dir_url(__DIR__) . 'assets/js/blockchain-interaction/main.js', Asset::BACKEND);
        $scripts[0]->withAttributes(["type" => "module"]);
        $scripts[0]->withTranslation(NFT_MARKETPLACE_CORE_TEXTDOMAIN . "-market", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
        $scripts[0]->withLocalize('nftMarketplaceCorelocation', array(
            'location' => plugin_dir_url(__DIR__),
        ));

        return $scripts;

		// {{/if}}
		// {{/if}}

	}
	// {{/if}}
    function addTypeAttribute($tag, $handle, $src)
    {
        // if not your script, do nothing and return original $tag
        if (NFT_MARKETPLACE_CORE_TEXTDOMAIN . "-market" !== $handle) {
            return $tag;
        }
        // change the script tag by adding type="module" and return it.
        $tag = '<script type="module" src="' . esc_url($src) . '" id="'.NFT_MARKETPLACE_CORE_TEXTDOMAIN . "-market".'" ></script>';
        return $tag;
    }

}
