<?php

namespace NFT_Marketplace_Core\Backend;

use NFT_Marketplace_Core\Backend\ActDeact\CreateTables;

/**
 * NFT Marketplace Core
 *
 * Builds the table used for showing the Deployed Contracts.
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 * $END$
 */
class ListTableImportQueue extends ListTableCopy
{

	/**
	 * Fallback function for displaying the column data
	 *
	 * @param $item
	 * @param $column_name
	 * @return mixed|void
	 * @since 1.0.0
	 */
	protected function column_default($item, $column_name)
	{
		return $item[$column_name];
	}

	protected function column_term_id($item)
	{
		if (!(($term = get_term($item["blockchain_id"])) instanceof \WP_Term)) {
			return esc_html__("Unknown", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
		}

		return $term->name;
	}

	protected function column_errors($item)
	{
		global $wpdb;
		$table = $wpdb->prefix . "nft_marketplace_core_queue_errors";
		$data = $wpdb->get_results("SELECT * FROM $table  WHERE queue_item =  " . $item["id"]);
		if (count($data) === 0) {
			return esc_html__("None", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
		} else {
			?>
			<a href="<?php echo add_query_arg([
				"errors" => $item["id"]
			]); ?>"
			   class="button-secondary"><?php esc_html_e("Check Errors", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
			<?php
		}
	}

	protected function column_is_imported($item)
	{
		return $item["is_imported"] === "1" ? esc_html__("Yes", NFT_MARKETPLACE_CORE_TEXTDOMAIN) : esc_html__("No", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
	}

	protected function column_actions($item)
	{
		?>
		<form method="post" style="margin-bottom: 12px">
			<input hidden="hidden" name="nft_marketplace_core_import_nft"
				   value="<?php esc_attr_e(json_encode($item)); ?>">
			<button type="submit" href="#"
					class="button-primary"><?php $item["is_imported"] === "0" ? esc_html_e("Import Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN) : esc_html_e("Import Again", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>
		</form>

		<?php if ($item["is_imported"] === "1") { ?>
		<a target="_blank" style="margin-bottom: 12px" href="<?php echo get_permalink($item['post_id']) ?>"
		   class="button-primary"><?php esc_html_e("View post", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
	<?php } ?>
		<form method="post">
			<input hidden="hidden" name="nft_marketplace_core_delete_queue" value="<?php esc_attr_e($item["id"]); ?>">
			<button type="submit" href="#" style="background: red;border-color: red;"
					class="button-primary"><?php esc_html_e("Remove", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
		</form>
		<?php
	}

	/**
	 * @return void
	 * @since 1.0.0
	 */
	public function prepare_items()
	{
		global $wpdb;
		$posts_per_page = 50;
		$columns = $this->get_columns();
		$hidden = $this->get_hidden_columns();
		$sortable = $this->get_sortable_columns();
		$data = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "nft_marketplace_core_queue LIMIT " . $posts_per_page, ARRAY_A);

		//usort( $data, array( &$this, 'sort_data' ) );
		$currentPage = $this->get_pagenum();
		$totalItems = count($data);

		$this->set_pagination_args(array(
			'total_items' => $totalItems,
			'per_page' => $posts_per_page
		));

		$data = array_slice($data, (($currentPage - 1) * $posts_per_page), $posts_per_page);

		$this->_column_headers = array($columns, $hidden, $sortable);
		$this->items = $data;
	}

	/**
	 * Gets a list of columns.
	 *
	 * The format is:
	 * - `'internal-name' => 'Title'`
	 *
	 * @return array
	 * @since 1.0.0
	 * @abstract
	 *
	 */
	public function get_columns()
	{
		return [
			"id" => esc_html__("ID", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"address" => esc_html__("Address", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"token" => esc_html__("Token ID", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"term_id" => esc_html__("Blockchain", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"contract_type" => esc_html__("Contract Type", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"post_id" => esc_html__("Post ID", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"added_at" => esc_html__("Added At", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"is_imported" => esc_html__("Is Imported?", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"errors" => esc_html__("Errors", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"actions" => esc_html__("Actions", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
		];
	}

	/**
	 * @return void
	 * @since 1.0.0
	 */
	private function table_data()
	{
	}

	/**
	 * @return array
	 * @since 1.0.0
	 */
	private function get_hidden_columns()
	{
		return [];
	}
}
