<?php

namespace NFT_Marketplace_Core\Backend;

use NFT_Marketplace_Core\Backend\ActDeact\CreateTables;

/**
 * NFT Marketplace Core
 *
 * Builds the table used for showing the Deployed Contracts.
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 * $END$
 */
class ListTableImportQueueErrors extends ListTableCopy
{

	/**
	 * Fallback function for displaying the column data
	 *
	 * @param $item
	 * @param $column_name
	 * @return mixed|void
	 * @since 1.0.0
	 */
	protected function column_default($item, $column_name)
	{
		return $item[$column_name];
	}

	/**
	 * @return void
	 * @since 1.0.0
	 */
	public function prepare_items()
	{
		global $wpdb;
		$posts_per_page = 50;
		$columns = $this->get_columns();
		$hidden = $this->get_hidden_columns();
		$sortable = $this->get_sortable_columns();
		$mainError = isset($_GET["errors"]) && is_numeric($_GET["errors"]) ? "WHERE queue_item = ". $_GET["errors"] : "";
		$data = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "nft_marketplace_core_queue_errors $mainError  LIMIT " . $posts_per_page, ARRAY_A);

		//usort( $data, array( &$this, 'sort_data' ) );
		$currentPage = $this->get_pagenum();
		$totalItems = count($data);

		$this->set_pagination_args(array(
			'total_items' => $totalItems,
			'per_page' => $posts_per_page
		));

		$data = array_slice($data, (($currentPage - 1) * $posts_per_page), $posts_per_page);

		$this->_column_headers = array($columns, $hidden, $sortable);
		$this->items = $data;
	}

	/**
	 * Gets a list of columns.
	 *
	 * The format is:
	 * - `'internal-name' => 'Title'`
	 *
	 * @return array
	 * @since 1.0.0
	 * @abstract
	 *
	 */
	public function get_columns()
	{
		return [
			"id" => esc_html__("ID", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"error" => esc_html__("Error Message", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			"added_at" => esc_html__("Happened At", NFT_MARKETPLACE_CORE_TEXTDOMAIN),
		];
	}

	/**
	 * @return void
	 * @since 1.0.0
	 */
	private function table_data()
	{
	}

	/**
	 * @return array
	 * @since 1.0.0
	 */
	private function get_hidden_columns()
	{
		return [];
	}
}
