<?php

namespace NFT_Marketplace_Core\Backend\ActDeact;


/**
 * NFT Marketplace Core
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class CreatePages
{

    public static $defaultPages = [
        [
            "title" => "NFTs Manager",
            "slug" => "manage-your-nfts"
        ],
        [
            "title" => "Connect your wallet",
            "slug" => "connect-your-wallet"
        ],
        [
            "title" => "NFT Listings",
            "slug" => "nft-listings"
        ],
    ];

    /**
     * @return bool
     * @since 3.2.0
     */
    public function run($pages = null) {
        $slugs = [];
        $pages = $pages ?? self::$defaultPages;

        // create all required pages
        foreach ($pages as $page) {
            if (is_wp_error($this->createPage($page["title"], $page["slug"]))) {
                $slugs[] = $page["slug"];
            }
        }

        if (!is_page($slugs)){
            set_transient('nft_marketplace_core_could_not_create_pages', $slugs, 36000);
            return false;
        }

        return true;
    }

    /**
     * Common function for creating WordPress pages.
     * @param string $title
     * @param string $slug
     * @return int|void|\WP_Error
     * @since 3.0.1
     */
    private function createPage($title, $slug)
    {
        $check_page_exist = get_page_by_title($title, 'OBJECT', 'page');
        // Check if the page already exists
        if (empty($check_page_exist)) {
            return wp_insert_post(
                array(
                    'comment_status' => 'close',
                    'ping_status' => 'close',
                    'post_author' => 1,
                    'post_title' => ucwords($title),
                    'post_name' => strtolower(str_replace(' ', '-', trim($slug))),
                    'post_status' => 'publish',
                    'post_content' => '',
                    'post_type' => 'page',
                )
            );
        }
    }
}
