<?php

namespace NFT_Marketplace_Core\Backend\ActDeact;


/**
 * NFT Marketplace Core
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class CreateTables
{

	private $prefix;
	private $charset;
	private $tables = ["offers", "transactions", "logs", 'logsValue', "contracts", "queue", "queue_errors"];

	/**
	 * @throws \Exception
	 */
	public function __construct()
	{
		global $wpdb;

		$this->prefix = $wpdb->prefix;
		$this->charset = $wpdb->get_charset_collate();

		require_once(ABSPATH . 'wp-admin/includes/upgrade.php');

		foreach ($this->tables as $table) {
			$tableFunc = $this->$table();
			if (!maybe_create_table($tableFunc["tableName"], $tableFunc["sql"])) {
				throw new \Exception("Could not create table " . $tableFunc["tableName"]);
			}
		}
	}


	private function queue()
	{
		$tableName = $this->prefix . 'nft_marketplace_core_queue';
		$ref = $this->prefix . "posts";

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
			(
				id            bigint          NOT NULL primary key AUTO_INCREMENT,
				post_id       bigint unsigned NOT NULL,
				address       varchar(144)    NOT NULL,
				contract_type varchar(144)    NOT NULL,
				token         int(11)         NOT NULL,
				blockchain_id int(3)          NOT NULL,
				is_imported   int(1)          NOT NULL DEFAULT 0,
				added_at      TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
				UNIQUE KEY id (id),
				FOREIGN KEY (post_id) REFERENCES $ref (ID) ON DELETE CASCADE
			) " . $this->charset . ";
        ";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}

	private function queue_errors()
	{
		$tableName = $this->prefix . 'nft_marketplace_core_queue_errors';
		$ref = $this->prefix . 'nft_marketplace_core_queue';

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
			(
				id            bigint          NOT NULL primary key AUTO_INCREMENT,
				error         TEXT    		  NOT NULL,
				queue_item    bigint    	  NOT NULL,
				added_at      TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
				UNIQUE KEY id (id),
				FOREIGN KEY (queue_item) REFERENCES $ref (id) ON DELETE CASCADE
			) " . $this->charset . ";
        ";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}

	private function offers()
	{
		$tableName = $this->prefix . 'nft_marketplace_core_offers';

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
            (
                id                  bigint          NOT NULL primary key AUTO_INCREMENT,
                nft_id              bigint unsigned NOT NULL,
                listingId           varchar(144)    NOT NULL,
                offeror             TEXT            NOT NULL,
                quantityWanted      float           NOT NULL,
                currency            bigint          NOT NULL,
                pricePerToken       bigint          NOT NULL,
                expirationTimestamp TIMESTAMP       NOT NULL DEFAULT CURRENT_TIMESTAMP,
                UNIQUE KEY id (id),
                FOREIGN KEY (nft_id) REFERENCES " . $this->prefix . "posts (ID)
            ) " . $this->charset . ";";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}

	private function transactions()
	{
		$tableName = $this->prefix . 'nft_marketplace_core_transactions';

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
            (
                id                   bigint          NOT NULL primary key AUTO_INCREMENT,
                nft_id               bigint unsigned NOT NULL,
                transaction_data     varchar(144)    NOT NULL,
                transaction_data_raw TEXT            NOT NULL,
                price                float           NOT NULL,
                customer             bigint          NOT NULL,
                seller               bigint          NOT NULL,
                registered_date      TIMESTAMP       NOT NULL DEFAULT CURRENT_TIMESTAMP,
                finished             smallint(5)     NOT NULL DEFAULT 0,
                UNIQUE KEY id (id),
                FOREIGN KEY (nft_id) REFERENCES " . $this->prefix . "posts (ID)
            ) " . $this->charset . ";";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}

	private function logs()
	{
		$tableName = $this->prefix . 'nft_marketplace_core_logs';
		$ref = $this->prefix . "posts";

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
            (
                id       bigint          NOT NULL primary key AUTO_INCREMENT,
                nft_id   bigint unsigned NOT NULL,
                log_type int(3)          NOT NULL,
                log_date TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
                UNIQUE KEY id (id),
                FOREIGN KEY (nft_id) REFERENCES $ref (ID) ON DELETE CASCADE
            ) " . $this->charset . ";
        ";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}

	private function logsValue()
	{
		$ref = $this->prefix . 'nft_marketplace_core_logs';
		$tableName = $this->prefix . 'nft_marketplace_core_logs_values';

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
            (
                id         bigint       NOT NULL primary key AUTO_INCREMENT,
                log_id     bigint       NOT NULL,
                log_value  varchar(244) NOT NULL,
                log_string varchar(244) NOT NULL,
                UNIQUE KEY id (id),
                FOREIGN KEY (log_id) REFERENCES $ref (ID) ON DELETE CASCADE
            ) " . $this->charset . ";
       ";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}

	private function contracts()
	{
		$tableName = $this->prefix . 'nft_marketplace_core_contracts';
		$ref = $this->prefix . "term_taxonomy";

		$sql = "
            CREATE TABLE IF NOT EXISTS $tableName
            (
                id                     bigint          NOT NULL primary key AUTO_INCREMENT,
                taxonomy_blockchain_id bigint unsigned NOT NULL,
                contract_address       varchar(144)    NOT NULL,
                version                varchar(144)    NOT NULL,
                is_deployed            smallint(5)     NOT NULL,
                listing_price          float           NOT NULL,
                contract_type          varchar(255) DEFAULT 'proprietary',
                contract_owner         varchar(255) DEFAULT 'unknown',
                UNIQUE KEY id (id),
                FOREIGN KEY (taxonomy_blockchain_id) REFERENCES $ref (term_taxonomy_id)
            ) " . $this->charset . ";
        ";

		return [
			"tableName" => $tableName,
			"sql" => $sql
		];
	}
}
