<?php

if (isset($_POST["nft_listing_price"])) {
    global $wpdb;
    $termData = get_term_by('slug', $_POST["nft_listing_blockchains"], "nft_listing_blockchains");

    if ($termData === false || !is_numeric($_POST["nft_listing_price"])) {
        ?>

        <div id="ajax-response">
            <div class="error">
                <p><?php esc_html_e("Please check if you have set the price correctly.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
            </div>
        </div>

        <?php
    } elseif (!isset($_POST['nft_listing_result']) || !preg_match("/^0x[a-fA-F0-9]{40}$/", $_POST['nft_listing_result'])) {
        ?>
        <div id="ajax-response">
            <div class="error">
                <p><?php esc_html_e("The contract data is empty, did you really deploy the contract?", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
            </div>
        </div>
        <?php
    } else {
        $wpdb->insert($wpdb->prefix . "nft_marketplace_core_contracts", [
            "taxonomy_blockchain_id" => $termData->term_id,
            "is_deployed" => "1",
            "version" => NFT_MARKETPLACE_CORE_VERSION . '(Marketplace V3)',
            "listing_price" => $_POST["nft_listing_price"],
            "contract_address" => $_POST['nft_listing_result'],
            "contract_type" => "thirdweb",
            "contract_owner" => $_POST['nft_listing_address']
        ]);
    }
}

?>

<form method="post" id="nft-marketplace-core-thirdweb-form-to-deploy" class="form-wrap">
    <h2><?php esc_html_e("Deploy Contract", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h2>
    <div class="form-field form-required term-slug-wrap">
        <label for="nft_listing_address">
            <?php esc_html_e("Recipient Address:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
        </label>
        <br/>
        <input name="nft_listing_address" id="nft_listing_address" type="text" value="">
        <p class="description"><?php esc_html_e("This is useful if you are deploying this contract for a 3rd party and want to take fees for your service.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>

    </div>
    <div class="form-field form-required term-slug-wrap">
        <label for="nft_listing_price">
            <?php esc_html_e("Platform fees:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> <span style="color: red">*</span>
        </label>
        <br/>
        <input required="true" name="nft_listing_price" id="nft_listing_price" type="number" step="0.01" value="">
        <p class="description"><?php esc_html_e("Get additional fees for all primary sales that happen on this contract.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
    </div>

    <input hidden data-ignore="true" name="nft_listing_result" id="nft_listing_result" type="text" value="">
    <input hidden data-ignore="true" name="nft_listing_name" id="nft_listing_name" type="text" value="<?php esc_attr_e(get_bloginfo('name')); ?>">

    <div class="form-field form-required term-slug-wrap">
        <label for="nft-change-blockchain" required="true"
        ><?php esc_html_e("Network/Chain:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> <span style="color: red">*</span>
        </label>
        <br>

        <?php $items = get_terms(array(
            'taxonomy' => 'nft_listing_blockchains',
            'hide_empty' => false,
        )); ?>
        <select required name="nft_listing_blockchains" id="nft-change-blockchain" data-ignore="true" class="postform"
                style="width:100%;">
            <option value="" selected disabled
                    hidden><?php esc_html_e("Choose here", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></option>
            <?php foreach ($items as $item) : ?>
                <option value="<?php echo esc_attr($item->slug); ?>"
                        data-blockchain="<?php echo esc_attr(json_encode(get_term_meta($item->term_id))); ?>"
                        id="term-id-<?php echo esc_attr($item->term_id); ?>"><?php echo esc_html($item->name); ?></option>
            <?php endforeach; ?>
        </select>
        <p class="description"><?php esc_html_e("Select the blockchain where you want to deploy the contract to.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
    </div>

    <div style="display: flex; align-items: center;justify-content: space-between">
        <button type="submit"
                class="button button-primary"><?php esc_html_e("Deploy Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>

        <div style="margin-right: 45px">
            <span class="dashicons dashicons-shield" style="color: green"></span>
            <a href="https://gateway.ipfscdn.io/ipfs/QmNgNaLwzgMxcx9r6qDvJmTFam6xxUxX7Vp8E99oRt7i74/" target="_blank"> <?php esc_html_e("Audited contract!", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> </a>
        </div>
    </div>
</form>
