<?php

use NFT_Marketplace_Core\Internals\ContractHelperThirdWeb;
use NFT_Marketplace_Core\Internals\Metas\BlockchainMeta;

if (isset($_POST["nft_marketplace_core_import_blockchain"])) {
    global $wpdb;
    $termData = get_term_by('slug', $_POST["nft_listing_blockchains"], "nft_listing_blockchains");

    if (is_wp_error($termData)) {
        ?>

        <div id="ajax-response">
            <div class="error">
                <p><?php esc_html_e("Could not find the specified blockchain inside your WordPress.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
            </div>
        </div>

        <?php
    }


    try {
        $marketplace = new ContractHelperThirdWeb(get_term_meta($termData->term_id, BlockchainMeta::rpc, true), $_POST["contract_address"]);
        $fees = $marketplace->getMarketplaceFeeInfo();

        $feeInPercentage = $fees->elem_2->toString() / 100;

        $insert = $wpdb->insert($wpdb->prefix . "nft_marketplace_core_contracts", [
            "taxonomy_blockchain_id" => $termData->term_id,
            "is_deployed" => "1",
            "version" => "2.0.0",
            "listing_price" => $feeInPercentage,
            "contract_address" => $_POST['contract_address'],
            "contract_type" => "thirdweb",
            "contract_owner" => $fees->elem_1
        ]);

        if (is_wp_error($insert)) {
            ?>
                <div id="ajax-response">
                    <div class="error">
                        <p>
                            <?php esc_html_e("Could not save the contract to database.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
                        </p>
                    </div>
                </div>
            <?php

        } else {
            ?>
                <div id="ajax-response">
                    <div class="notice-success">
                        <p>
                            <?php esc_html_e("Marketplace contract imported.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
                        </p>
                    </div>
                </div>
            <?php
        }
    } catch (\Exception $exception) {
        ?>

        <div id="ajax-response">
            <div class="error">
                <p>
                    <?php esc_html_e("Could not verify if the contract exists, check the following:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
                    <ol>
                        <li><?php esc_html_e("Your RPC is working properly.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></li>
                        <li><?php esc_html_e("The contract address you have entered is correct.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></li>
                        <li><?php esc_html_e("The contract address is on the same chain as the option you have selected.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></li>
                    </ol>

                <?php esc_html_e("RAW ERROR: ".$exception->getMessage()); ?>
                </p>
            </div>
        </div>

        <?php


    }

//    if ($termData === false || !is_numeric($_POST["nft_listing_price"])) {
//        ?>
<!---->
<!--        <div id="ajax-response">-->
<!--            <div class="error">-->
<!--                <p>--><?php //esc_html_e("Please check if you have set the price correctly.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><!--</p>-->
<!--            </div>-->
<!--        </div>-->
<!---->
<!--        --><?php
//    } elseif (!isset($_POST['nft_listing_result']) || !preg_match("/^0x[a-fA-F0-9]{40}$/", $_POST['nft_listing_result'])) {
//        ?>
<!--        <div id="ajax-response">-->
<!--            <div class="error">-->
<!--                <p>--><?php //esc_html_e("The contract data is empty, did you really deploy the contract?", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><!--</p>-->
<!--            </div>-->
<!--        </div>-->
<!--        --><?php
//    } else {
//        $wpdb->insert($wpdb->prefix . "nft_marketplace_core_contracts", [
//            "taxonomy_blockchain_id" => $termData->term_id,
//            "is_deployed" => "1",
//            "version" => "2.0.0",
//            "listing_price" => $_POST["nft_listing_price"],
//            "contract_address" => $_POST['nft_listing_result'],
//            "contract_type" => "thirdweb",
//            "contract_owner" => $_POST['nft_listing_address']
//        ]);
//    }
}

?>

<form method="post" class="form-wrap">
    <h2><?php esc_html_e("Import Existing Contract", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h2>
    <p><?php esc_html_e("Already have a Marketplace Contract deployed? Complete the fields below and start using it."); ?></p>
    <div class="form-field form-required term-slug-wrap">
        <label for="contract_address">
            <?php esc_html_e("Contract Address:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
        </label>
        <br/>
        <input name="contract_address" id="contract_address" type="text" value="">
        <p class="description"><?php esc_html_e("The address of the contract you want to use.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
    </div>
    <div class="form-field form-required term-slug-wrap">

        <input hidden="hidden" name="nft_marketplace_core_import_blockchain" value="true">

        <label for="nft-change-blockchain" required="true"
        ><?php esc_html_e("Network/Chain:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> <span style="color: red">*</span>
        </label>
        <br>

        <?php $items = get_terms(array(
            'taxonomy' => 'nft_listing_blockchains',
            'hide_empty' => false,
        )); ?>
        <select required name="nft_listing_blockchains" class="postform"
                style="width:100%;">
            <option value="" selected disabled
                    hidden><?php esc_html_e("Choose here", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></option>
            <?php foreach ($items as $item) : ?>
                <option value="<?php echo esc_attr($item->slug); ?>"
                        data-blockchain="<?php echo esc_attr(json_encode(get_term_meta($item->term_taxonomy_id))); ?>"
                        id="term-id-<?php echo esc_attr($item->term_id); ?>"><?php echo esc_html($item->name); ?></option>
            <?php endforeach; ?>
        </select>
        <p class="description"><?php esc_html_e("Select the blockchain where the contract is deployed.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
    </div>

    <div style="display: flex; align-items: center;justify-content: space-between">
        <button type="submit"
                class="button button-primary"><?php esc_html_e("Import Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>

        <div style="margin-right: 45px;color:red;">
            <span style="color:red;" class="dashicons dashicons-warning" style="color: green"></span>
            <a style="color:red;" href="https://thirdweb.com/thirdweb.eth/Marketplace"
               target="_blank"> <?php esc_html_e("Only ThirdWeb contracts!", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> </a>
        </div>
    </div>
</form>
