<?php

use NFT_Marketplace_Core\Backend\ListTableImportQueue;
use NFT_Marketplace_Core\backend\ListTableImportQueueErrors;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;

if (!defined('ABSPATH')) {
	exit;
}

global $wpdb;

if (isset($_POST["nft_marketplace_core_clear_queue"])) {
	$wpdb->query("TRUNCATE TABLE " . $wpdb->prefix . "nft_marketplace_core_queue");
}

if (isset($_POST["nft_marketplace_core_delete_queue"])) {
	if (!is_numeric($_POST["nft_marketplace_core_delete_queue"])) {
		wpdesk_wp_notice_error(esc_html__("Item could not be removed from queue!", NFT_MARKETPLACE_CORE_TEXTDOMAIN));
	}

	$table_name = $wpdb->prefix . "nft_marketplace_core_queue";
	$deleted_rows = $wpdb->query($wpdb->prepare("DELETE FROM {$table_name} WHERE id = %s", $_POST["nft_marketplace_core_delete_queue"]));

	wpdesk_wp_notice_success(esc_html__("Item removed from queue!", NFT_MARKETPLACE_CORE_TEXTDOMAIN));
}

if (isset($_POST["nft_marketplace_core_import_nft"])) {
	$json = json_decode(stripslashes($_POST["nft_marketplace_core_import_nft"]), true);
	$isValid = is_array($json);
	if ($isValid && is_numeric($json["id"])) {
		try {
			if ($json["is_imported"] === "1") {
				$wpdb->update($wpdb->prefix . "nft_marketplace_core_queue",
					array(
						"is_imported" => 0,
					),
					array(
						"id" => $json["id"],
					));
			}
			Marketplace::runQueue([$json], $json["blockchain_id"]);

			wpdesk_wp_notice_success(esc_html__("Item imported successfully!", NFT_MARKETPLACE_CORE_TEXTDOMAIN));
		} catch (\Exception $exception) {
			$wpdb->insert($wpdb->prefix . "nft_marketplace_core_queue_errors", array(
				"queue_item" => $json["id"],
				"error" => $exception->getMessage(),
			));

			wpdesk_wp_notice_error(esc_html__("Could not import the item, please check the logs.", NFT_MARKETPLACE_CORE_TEXTDOMAIN));
		}
	} else {
		wpdesk_wp_notice_error(esc_html__("Something went wrong with the data provided.", NFT_MARKETPLACE_CORE_TEXTDOMAIN));
	}
}

?>

<?php

if (isset($_GET["errors"]) && is_numeric($_GET["errors"])) {
	?>
	<div class='wrap nosubsub'>
		<h1 class='wp-heading-inline'>
			<?php esc_html_e("Error logs for", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
			#<?php esc_html_e($_GET["errors"]) ?>
		</h1>

		<div class="col-wrap">
			<div class="content" style="padding-top: 30px">
				<div class="col-wrap">
					<?php
					$table = new ListTableImportQueueErrors();
					$table->prepare_items();
					$table->display();
					?>
				</div>
			</div>
		</div>
	</div>
	<?php
	return;
} else if (isset($_GET["all-errors"])) {
	?>
	<div class='wrap nosubsub'>
		<h1 class='wp-heading-inline'>
			<?php esc_html_e("Latest Errors", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
		</h1>

		<div class="col-wrap">
			<div class="content" style="padding-top: 30px">
				<div class="col-wrap">
					<?php
					$table = new ListTableImportQueueErrors();
					$table->prepare_items();
					$table->display();
					?>
				</div>
			</div>
		</div>
	</div>
	<?php
	return;
}

?>

<div class='wrap nosubsub'>
	<h1 class='wp-heading-inline'>
		<?php esc_html_e("Import Collection", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
	</h1>

	<div class="col-wrap">
		<div class="content" style="padding-top: 30px">
			<div class="col-wrap">
				<a href="<?php echo add_query_arg([
					"all-errors" => true
				]) ?>" class="button primary"><?php esc_html_e("See All Errors") ?></a>
				<form method="post" style="display: inline">
					<?php submit_button(__("Empty Queue", NFT_MARKETPLACE_CORE_TEXTDOMAIN), 'default', 'nft_marketplace_core_clear_queue', false, [
						"style"=> "border-color:red;color:red;"
					]); ?>
				</form>
				<?php
				$table = new ListTableImportQueue();
				$table->prepare_items();
				$table->display();
				?>
			</div>
		</div>
	</div>
</div>
