<?php

namespace NFT_Marketplace_Core\Contracts;

use SWeb3\SWeb3;

class Factory
{
    /**
     * @param $nftContractType
     * @param string $address
     * @param SWeb3 $sWeb3
     * @param mixed ...$args
     * @return NFTContract
     * @throws \Exception
     */
    public static function getContractByType($nftContractType, string $address, SWeb3 $sWeb3, ...$args): NFTContract
    {
		if ($nftContractType === "ERC-721") {
			$nftContractType = "Collection";
		} else if ($nftContractType === "ERC-1155") {
			$nftContractType = "Edition";
		}
		$customContracts = apply_filters("nft_marketplace_core_contract_factory", [], $nftContractType);

		if (in_array($nftContractType, $customContracts)) {
			return new $nftContractType($address, $sWeb3, ...$args);
		}

        if (!class_exists($nftContractType)) {
            $className = "NFT_Marketplace_Core\Contracts\\" . $nftContractType;

            if (!class_exists($className)) {
                throw new \Exception("Could not determine what type of contract this is!");
            }

            return new $className($address, $sWeb3, ...$args);
        }

        return new $nftContractType($address, $sWeb3, ...$args);
    }
}
