<?php

namespace NFT_Marketplace_Core\Contracts;

use SWeb3\SWeb3;
use SWeb3\SWeb3_Contract;

abstract class NFTContract
{

    public const MetadataByTokenId = "";
    public const TotalSupply = "";
    protected SWeb3_contract $connection;
    protected string $address;

    /**
     * @param string $address
     * @param SWeb3 $sWeb3
     * @throws \Exception
     */
    public function __construct(string $address, SWeb3 $sWeb3) {
        $this->address = $address;
        $this->connection = new SWeb3_contract($sWeb3, $this->address, $this->getAbi());
    }

    /**
     * @return string
     * @since 3.0.0
     */
    public abstract function getContractType();

    /**
     * @return string
     * @since 3.0.0
     */
    public abstract function getThirdWebName();

    /**
     * @return integer
     * @since 3.0.0
     */
    public abstract function getTotalSupply();

    /**
     * @return string
     * @since 3.0.0
     */
    public abstract function getMetadataByTokenId($tokenID);

    /**
     * @return string
     * @throws \Exception
     * @since 4.0.0
     */
    public abstract function getAbi(): string;

    /**
     * Index 0 should be the token ID;
     * @throws \Exception
     * @since 4.0.0
     */
    public abstract function getOwnerOf(...$args): string;

    /**
     * @return mixed
     * @since 4.0.0
     */
    public function getBlockchainConnection() : SWeb3_Contract {
        return $this->connection;
    }
}
