<?php
/**
 * code
 *
 * @package   code
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Frontend\Extras;

use NFT_Marketplace_Core\Engine\Base;

/**
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class PageCategory extends PageGlobal
{
    public function initialize()
    {
        add_action('nft_marketplace_core_archive_before_grid', [$this, 'archive_ordering'], 20);
        add_action('nft_marketplace_core_archive_before_grid', [$this, 'archive_listings_count'], 10);
        add_action('nft_marketplace_core_archive_after_grid_template', [$this, 'archive_pagination']);
        add_action('nft_marketplace_core_archive_listing_query', [$this, 'single_nft_block']);
        add_action( 'nft_marketplace_core_author_after_grid', [$this, 'archive_pagination']);
    }

    //ARCHIVE NFT : PAGINATION
	// Keeping this function just for collection/author profile pagination.
    function archive_pagination()
    {
        global $wp_query;
//        $nr_prod = '9';
//
//        if (isset(get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_page'])) {
//            $nr_prod = get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_page'];
//        }

        $taxQuery = [];
        $termInHeader =  null;

        if (array_key_exists("nft-listing-category", $wp_query->query)) {
            $termInHeader = "nft-listing-category";
        } else if (array_key_exists("nft-listing-collection", $wp_query->query)) {
            $termInHeader = "nft-listing-collection";
        }

        if(!is_null($termInHeader)) {
            $nft_listing_single_cat = wp_get_post_terms(get_the_ID(), $termInHeader);

            $taxQuery = array(
                    array(
                        'taxonomy' => $termInHeader,
                        'field'    => 'id',
                        'terms'    => $nft_listing_single_cat[0]->term_id
                    )
                )
            ;
        }

        //@todo check for author!

		$author = wp_get_current_user();
		if (get_query_var('author_name')) {
			$author = get_user_by( 'slug', get_query_var( 'author_name' ) );
		}
        $the_query = new \WP_Query(array(
            'posts_per_page' => 4,
            'post_type' => 'nft-listing',
            'paged' => get_query_var('paged') ? (int)get_query_var('paged') : 1,
			'author__in' => array($author->ID),
            'tax_query' => $taxQuery
        ));
        $big = 999999999; // need an unlikely integer

        echo '<div class="modeltheme-pagination-holder col-md-12">';
            echo '<div class="modeltheme-pagination pagination">';
                echo paginate_links(array(
                    'base' => str_replace($big, '%#%', get_pagenum_link($big)),
                    'format' => '?paged=%#%',
                    'current' => max(1, (int)get_query_var('paged')),
                    'total' => $the_query->max_num_pages,
					'mid_size' => 1,
//                    'show_all' => false,
//                    'type' => 'plain',
//                    'end_size' => 2,
//                    'prev_next' => false,
//                    'add_args' => false,
//                    'add_fragment' => '',
                ));
            echo '</div>';
        echo '</div>';

        wp_reset_postdata();
    }


    // ARCHIVE NFT : QUERY LISTING COUNT
    function archive_listings_count()
    {
        global $wp_query;
        echo '<div class="nft-marketplace-taxonomy-count col-md-9">';
        $query_page = (get_query_var('paged')) ? get_query_var('paged') : 1;
        $posts_per_page = get_query_var('posts_per_page');
        $last_page = $posts_per_page * $query_page;
        $first_page = $last_page - $posts_per_page + 1;
        $total = $wp_query->found_posts;
        echo esc_html__('Showing ' . esc_attr($first_page) . ' - ' . esc_attr($last_page) . ' of ' . esc_attr($total) . ' results', NFT_MARKETPLACE_CORE_TEXTDOMAIN);
        echo '</div>';
    }


    // ARCHIVE NFT : ORDERING
    function archive_ordering()
    {
        if (!is_search()) {
            global $wp;
            $location = home_url($wp->request);
            echo '<div class="nft-marketplace-taxonomy-ordering col-md-3">';
            echo '<form class="nft-marketplace-ordering" method="get">'; ?>
            <select onchange="if(this.value !== '') document.location = '<?php echo esc_attr($location); ?>/?orderby=' + this.value">
                <option value=""><?php echo esc_html__('Default Sorting'); ?></option>
                <option value="title"<?php if (isset($_GET['order_by']) && $_GET['order_by'] == 'title') echo ' selected="selected"'; ?>><?php echo esc_html__('Sort by Title', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></option>
                <option value="date"<?php if (isset($_GET['order_by']) && $_GET['order_by'] == 'date') echo ' selected="selected"'; ?>><?php echo esc_html__('Sort by Date', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></option>
            </select><?php
            echo '<input type="hidden" name="paged" value="1">';
            echo '</form>';
            echo '</div>';
        }
    }
}
