<?php
/**
 * NFT_Marketplace_Core
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 */

/**
 * Get the settings of the plugin in a filterable way
 *
 * @since 2.0.0
 * @return array
 */
function nft_marketplace_core_get_settings() {
	return apply_filters( 'nft_marketplace_core_get_settings', get_option( NFT_MARKETPLACE_CORE_TEXTDOMAIN . '-settings' ) );
}

/**
 *
 * Helper function to prepare valid HTML input required for the frontend to call one of the contract's function
 *
 * @param $id string ID attribute, must be unique.
 * @param $functionName string The function we want to call on the contract.
 * @param $label string Label name.
 * @param $desc string Description.
 * @param $input string The HTML Input element.
 *
 * @return void
 * @since 1.0.0
 */
function nft_marketplace_core_create_input($id, $functionName, $label, $desc, $input) {
	echo '
        <div class="form-field form-required term-slug-wrap"
             data-function-name="'.$functionName.'"
             data-changed="false"
        >
            <label for="'.$id.'">'.$label.'</label>
    ';

	echo str_replace("<input", "<input name='$id' id='$id' ", $input);

	echo '
            <p class="description">'.$desc.'</p>
        </div>
    ';
}

/**
 *
 * Generate the dataset required for the Wallet to check and switch the Blockchain to the one that we need.
 * @param $termid string|string The Blockchain id
 *
 * @return string
 * @since 1.0.0
 */
function nft_marketplace_core_switch_dataset_attribute($termid) {
	return 'data-force-switch-to="'.esc_attr(json_encode(get_term_meta($termid),JSON_UNESCAPED_SLASHES)).'"';
}

/**
 * Hides the WordPress admin panel from users who are not admins.
 * @param $roles
 * @return bool|void
 * @since 4.0.0
 */
function nft_marketplace_core_check_user_role( $roles ) {
    if (!defined('ABSPATH')) {
        return;
    }
//variable for check user logged in
    if(!function_exists('wp_get_current_user')) {
        include(ABSPATH . "wp-includes/pluggable.php");
    }
    /*@ Check user logged-in */
    /*@ Get current logged-in user data */
    $user = wp_get_current_user();
    /*@ Fetch only roles */
    $currentUserRoles = $user->roles;
    /*@ Intersect both array to check any matching value */
    $isMatching = array_intersect( $currentUserRoles, $roles);
    $response = false;
    /*@ If any role matched then return true */
    if ( !empty($isMatching) ) :
        $response = true;
    endif;
    return $response;
}

$roles = [ 'customer', 'subscriber', 'nft_vendor' ];
if ( nft_marketplace_core_check_user_role($roles) ) :
    add_filter('show_admin_bar', '__return_false');
endif;

function nft_marketplace_core_cron_schedules($schedules){
	$value = 1;

	if (isset(get_option("nft_marketplace_core_panel_extras_tab")["nft_marketplace_core_cron"]) && is_numeric(get_option("nft_marketplace_core_panel_extras_tab")["nft_marketplace_core_cron"])) {
		$value = get_option("nft_marketplace_core_panel_extras_tab")["nft_marketplace_core_cron"];
	}

	if(!isset($schedules["5min"])){
		$schedules["nft_core_every_minute"] = array(
			'interval' => $value * 60,
			'display' => __('NFT Core Setting (default one minute)'));
	}

	return $schedules;
}
add_filter('cron_schedules','nft_marketplace_core_cron_schedules');
