<?php
/**
 * htdocs
 *
 * @package   htdocs
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Integrations;

use NFT_Marketplace_Core\Engine\Base;
use NFT_Marketplace_Core\Internals\RadioTaxonomy\WordPressRadioTaxonomy;

class BlockchainRadioTaxonomy extends Base
{
	private $taxonomiesToTransform = ["nft_listing_blockchains"];
	private $taxonomies = [];

	public function initialize()
	{
		// Launch each taxonomy class.
		add_action( 'wp_loaded', array( $this, 'launch' ) );
		add_action('admin_enqueue_scripts', array($this, 'admin_script'));
	}

	/**
	 * Enqueue Scripts
	 *
	 * @access public
	 * @return void
	 * @since  1.0
	 */
	public function admin_script($hook)
	{
		wp_register_script('radiotax', plugins_url('js/radiotax.js', __FILE__), array('jquery', 'inline-edit-post'), NFT_MARKETPLACE_CORE_VERSION, true);

		// Get admin screen id.
		$screen = get_current_screen();
		$screen_base = $screen ? $screen->base : '';
		$post_type = $screen ? $screen->post_type : '';
		$has_block_editor = is_callable(array($screen, 'is_block_editor')) && $screen->is_block_editor();

		/**
		 * Enqueue scripts.
		 */
		if (in_array($screen_base, array('post', 'edit')) && !$has_block_editor) {
			// If the post type has a radio taxonomy.
			if ($post_type && array_intersect($this->taxonomiesToTransform, get_object_taxonomies($post_type, 'names'))) {
				wp_enqueue_script('radiotax');
			}

		}
	}

	/**
	 * For each taxonomy that we are converting to radio buttons, store in taxonomies class property, ex: $this->taxonomies[categories]
	 *
	 * @access public
	 * @return object
	 * @since  1.0
	 */
	public function launch() {
		// Loop through selected taxonomies.
		foreach ( $this->taxonomiesToTransform as $radiotaxonomy ) {
			if ( taxonomy_exists( $radiotaxonomy ) ) {
				$this->taxonomies[$radiotaxonomy] = new WordPressRadioTaxonomy( $radiotaxonomy  );
			}
		}
	}
}
