<?php

/**
 * NFT Marketplace Core
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Integrations;

use NFT_Marketplace_Core\Contracts\Factory;
use NFT_Marketplace_Core\Engine\Base;
use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;
use function Amp\Iterator\concat;

/**
 * The various Cron of this plugin
 */
class Cron extends Base
{

	/**
	 * Initialize the class.
	 *
	 * @return void
	 */
	public function initialize()
	{
		/*
		 * Load CronPlus
		 */
		$args = array(
			// hourly, daily, twicedaily, weekly, monthly or timestamp for single event
			'recurrence' => 'nft_core_every_minute',
			'schedule' => 'schedule',
			'name' => 'import_collection',
			'cb' => array($this, 'importCollection'),
			'plugin_root_file' => 'nft-marketplace-core.php',
		);

		$cronplus = new \CronPlus($args);
		// Schedule the event
		$cronplus->schedule_event();
		// Remove the event by the schedule
		// $cronplus->clear_schedule_by_hook();
		// Jump the scheduled event
		// $cronplus->unschedule_specific_event();
	}

	/**
	 * Cron Hourly example
	 *
	 * @param int $id The ID.
	 * @return void
	 * @throws \Exception
	 * @since 2.0.0
	 */
	public function importCollection($id)
	{
		global $wpdb;
		$table = $wpdb->prefix . "nft_marketplace_core_queue";
		$table2 = $wpdb->prefix . "nft_marketplace_core_queue_errors";

		$limit = 50;

		if (isset(get_option("nft_marketplace_core_panel_extras_tab")["nft_marketplace_core_cron_limit"]) && is_numeric(get_option("nft_marketplace_core_panel_extras_tab")["nft_marketplace_core_cron_limit"])) {
			$limit = get_option("nft_marketplace_core_panel_extras_tab")["nft_marketplace_core_cron_limit"];
		}

		$queue = $wpdb->get_results("
		SELECT q.*
		FROM $table q
		LEFT JOIN $table2 e
		ON q.id = e.queue_item
		WHERE q.is_imported = 0
		AND e.error IS NULL
		GROUP BY q.blockchain_id LIMIT " . $limit, ARRAY_A);

		if (empty($queue)) return;

		Marketplace::runQueue($queue, $queue[0]['blockchain_id']);
	}

}
