<?php

namespace NFT_Marketplace_Core\Integrations;

use NFT_Marketplace_Core\Engine\Base;

/**
 * Handle integration with ModelTheme's plugin KYC - Know Your Customer
 *
 * @package   Nft_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class KYC extends Base
{

    /**
     * Initialize class.
     *
     * @return void
     * @since 3.2.1
     */
    public function initialize()
    {
        parent::initialize();

		add_filter('nft_marketplace_core_process_display_name', [$this, "attachVerifiedBadgeToUsernameDefault"]);

		if (is_plugin_active("mtkyc/mtkyc.php")) {
            add_filter('nft_marketplace_core_process_display_name', [$this, "attachVerifiedBadgeToUsername"] , 20);
            add_action('nft_marketplace_core_panel_account_settings_tab_after_form', [$this, "attachWidgetToPanel"]);
        }
    }

	/**
	 * @param $userId
	 * @return string
	 * @since 4.0.0
	 */
	public function attachVerifiedBadgeToUsernameDefault($userId): string
	{
		return get_the_author_meta('display_name',$userId);
	}

	/**
     * Handles displaying the badge everywhere there is a username
     * @return string
     * @since 3.2.1
     */
    public function attachVerifiedBadgeToUsername($userId): string
	{
        $displayName = get_the_author_meta('display_name',$userId);

        if (mtkyc_check_specific_user_status($userId) !== "approved") return $displayName;

        return "
        <svg width='24' height='24' viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'><rect width='24' height='24' stroke='none' fill='#000000' opacity='0'/>
            <g transform='matrix(0.42 0 0 0.42 12 12)' >
                <g style='' >
                    <g transform='matrix(1 0 0 1 0 0)' >
                        <polygon style='stroke: none; stroke-width: 1; stroke-dasharray: none; stroke-linecap: butt; stroke-dashoffset: 0; stroke-linejoin: miter; stroke-miterlimit: 4; fill: rgb(66,165,245); fill-rule: nonzero; opacity: 1;' points='5.62,-21 9.05,-15.69 15.37,-15.38 15.69,-9.06 21,-5.63 18.12,0 21,5.62 15.69,9.05 15.38,15.37 9.06,15.69 5.63,21 0,18.12 -5.62,21 -9.05,15.69 -15.37,15.38 -15.69,9.06 -21,5.63 -18.12,0 -21,-5.62 -15.69,-9.05 -15.38,-15.37 -9.06,-15.69 -5.63,-21 0,-18.12 ' />
                    </g>
                    <g transform='matrix(1 0 0 1 -0.01 0.51)' >
                        <polygon style='stroke: none; stroke-width: 1; stroke-dasharray: none; stroke-linecap: butt; stroke-dashoffset: 0; stroke-linejoin: miter; stroke-miterlimit: 4; fill: rgb(255,255,255); fill-rule: nonzero; opacity: 1;' points='-2.6,6.74 -9.09,0.25 -6.97,-1.87 -2.56,2.53 7,-6.74 9.09,-4.59 ' />
                    </g>
                </g>
            </g>
        </svg>
        <span class='username' data-username='".esc_attr($displayName)."'>".esc_html__($displayName)."</span>
        ";
    }

    /**
     * Handles displaying the verification widget on the Enefti Panel
     * @return void
     * @since 3.2.1
     */
    public function attachWidgetToPanel()
    {
        echo do_shortcode("[kyc_verification]");
    }
}
