<?php

namespace NFT_Marketplace_Core\Integrations;

/**
 * NFT_Marketplace_Core
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 */


use NFT_Marketplace_Core\Engine\Base;
use NFT_Marketplace_Core\Integrations\NFTForm;
use NFT_Marketplace_Core\Internals\Helpers\Error;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;
use NFT_Marketplace_Core\Internals\Helpers\VerifyConfig;
use NFT_Marketplace_Core\Internals\Metas\BlockchainMeta;
use NFT_Marketplace_Core\Internals\Metas\NFTMeta;

/**
 * NFT_Marketplace_Core
 *
 * Creates the sidebar for NFT Marketplace Core.
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class Sidebar extends Base
{

    /**
     * Initialize class.
     *
     * @return void
     * @since 2.0.0
     */
    public function initialize()
    {
        parent::initialize();

        add_action('widgets_init',[$this, "buildSidebar"]);
    }

    /**
     * Builds the sidebar.
     *
     * @return void
     * @since 3.2.1
     */
    function buildSidebar() {
        register_sidebar( array(
            'name' => __( 'Sidebar for Enefti - NFT Marketplace Core', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'id' => 'nft-listing',
            'description' => __( 'Appears on /nft-listings page and /search page', NFT_MARKETPLACE_CORE_TEXTDOMAIN ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title" style="display: inline-block">',
            'after_title' => '</h3>',
            'before_sidebar' => '<form method="GET" style="display: flex;flex-direction: column;gap: 20px;">',
            'after_sidebar' => '
            	<input type="submit" class="btnnt single_nft_button" style="color:white;background:#D01498;width:100%;" value="'.esc_html__("Apply Filters",NFT_MARKETPLACE_CORE_TEXTDOMAIN).'">
				</form>
                <input id="resetAllFilters" type="button" class="btnnt single_nft_button" style="width:100%" value="' . esc_html__("Reset All", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . '">
                <script>
                    const resetFiltersElement = document.getElementById("resetAllFilters");
                    resetFiltersElement.addEventListener("click", () => {
					    const url = new URL(window.location);
                        if (url.searchParams.size !== 0) {
                            window.location.href = `${url.origin}${url.pathname}`;
                        }
                    });
                </script>
            ',
        ) );
    }


}
