<?php

namespace NFT_Marketplace_Core\Integrations\Widgets;

use WPH_Widget;

/**
 * Widget for filtering NFTs by their terms.
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class PriceFilterWidget extends WPH_Widget
{
	/**
	 * Initialize the widget
	 *
	 * @return void
	 */
	public function __construct()
	{ // phpcs:ignore
		$args = array(
			'label' => \__('NFT: Price Filter', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'description' => \__('Filter prices for NFTs.', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'slug' => 'nft-marketplace-core-widget-taxonomy-price',
			'options' => array('cache' => true)
		);

		$args['fields'] = array();
		// Create widget
		$this->create_widget($args);
	}

	/**
	 * Output function
	 *
	 * @param array $args The argument shared to the output from WordPress.
	 * @param array $instance The settings saved.
	 * @return void
	 * @since 4.0.0
	 */
	public function widget($args, $instance)
	{ //phpcs:ignore
		// Only display the widget on the custom post type
		// Display the widget content
		echo $args['before_widget'];
		?>
		<div class="faq-drawer">
			<input id="faq-drawer-<?php esc_attr_e($args["widget_id"]); ?>"
				   class="faq-drawer__trigger thoidinput widget" type="checkbox"/>
			<label class="faq-drawer__title" for="faq-drawer-<?php esc_attr_e($args["widget_id"]); ?>">
				<?php
				echo $args['before_title'] . esc_html__('Price Filter', NFT_MARKETPLACE_CORE_TEXTDOMAIN) . $args['after_title']; // Escaped and translated title
				?>
			</label>
			<div class="faq-drawer__content-wrapper">
				<div class="faq-drawer__content">
					<?php
					// Display the price filter form
					$this->display_price_filter_form();
					?>
				</div>
			</div>
		</div>
		<?php
		echo $args['after_widget'];
	}

	private function display_price_filter_form()
	{
		?>
		<div style="display: flex;align-items: center;gap: 20px">
			<div>
				<label for="price_min"><?php esc_html_e('Minimum Price:', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></label>
				<input type="number" name="price_min" id="price_min"
					   placeholder="0"
					   value="<?php echo isset($_GET['price_min']) ? esc_attr($_GET['price_min']) : ''; ?>">

			</div>
			<div>
				<label for="price_max"><?php esc_html_e('Maximum Price:', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></label>
				<input type="number" name="price_max" id="price_max"
					   placeholder="1000"
					   value="<?php echo isset($_GET['price_max']) ? esc_attr($_GET['price_max']) : ''; ?>">

			</div>
		</div>
		<?php
	}

	/**
	 * Initialize the class.
	 *
	 * @return void
	 */
	public function initialize()
	{
		\add_action(
			'widgets_init',
			static function () {
				\register_widget('NFT_Marketplace_Core\Integrations\Widgets\PriceFilterWidget');
			}
		);
	}
}
