<?php

namespace NFT_Marketplace_Core\Integrations\Widgets;

use WPH_Widget;

/**
 * Widget for filtering NFTs by their terms.
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class StatusFilterWidget extends WPH_Widget
{
	/**
	 * Initialize the widget
	 *
	 * @return void
	 */
	public function __construct()
	{ // phpcs:ignore
		$args = array(
			'label' => \__('NFT: Status Filter', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'description' => \__('Filter NFTs by their statuses', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'slug' => 'nft-marketplace-core-widget-status-filter',
			'options' => array('cache' => true)
		);

		$args['fields'] = array();
		// Create widget
		$this->create_widget($args);
	}

	/**
	 * Output function
	 *
	 * @param array $args The argument shared to the output from WordPress.
	 * @param array $instance The settings saved.
	 * @return void
	 * @since 4.0.0
	 */
	public function widget($args, $instance)
	{ //phpcs:ignore
		// Only display the widget on the custom post type
		// Display the widget content
		echo $args['before_widget'];
		?>
		<div class="faq-drawer">
			<input id="faq-drawer-<?php esc_attr_e($args["widget_id"]); ?>"
				   class="faq-drawer__trigger thoidinput widget" type="checkbox"/>
			<label class="faq-drawer__title" for="faq-drawer-<?php esc_attr_e($args["widget_id"]); ?>">
				<?php
				echo $args['before_title'] . esc_html__('Status', NFT_MARKETPLACE_CORE_TEXTDOMAIN) . $args['after_title']; // Escaped and translated title
				?>
			</label>
			<div class="faq-drawer__content-wrapper">
				<div class="faq-drawer__content">
					<?php
					// Display the price filter form
					$this->display_price_filter_form($args, $instance);
					?>
				</div>
			</div>
		</div>
		<?php
		echo $args['after_widget'];
	}

	public function display_price_filter_form($args, $instance)
	{ //phpcs:ignore
		$out = "";
		$terms = ["Listed", "Not Listed", "Starting Soon"];
		// "Open", "Sold", "Cancelled", "Pending", "Bidded", "Not Bidded", "Expired", "On Auction", "Not On Auction", "On Sale", "Not On Sale"
		$out .= '<fieldset id="switch" class="radio">';
		/** @var \WP_Term $term */
		foreach ($terms as $term) {
			$selected = isset($_GET['status']) && $_GET['status'] === $term ? "checked" : "";

			$out .= '
				<div>
					<input ' . $selected . ' name="status" id="status-' . esc_attr($term) . '" type="radio" value="' . esc_attr($term) . '">
					<label for="status-' . esc_attr($term) . '">' . esc_html__($term) . '</label>
				</div>
			';
		}
		$out .= '</fieldset>';
		echo $out; // phpcs:ignore
	}

	/**
	 * Initialize the class.
	 *
	 * @return void
	 */
	public function initialize()
	{
		\add_action(
			'widgets_init',
			static function () {
				\register_widget('NFT_Marketplace_Core\Integrations\Widgets\StatusFilterWidget');
			}
		);
	}
}
