<?php

namespace NFT_Marketplace_Core\Internals;

use PHPUnit\Util\Exception;
use SWeb3\SWeb3;
use SWeb3\SWeb3_Contract;

class ContractHelperThirdWeb
{

    private $provider;
    private $sweb3;


    public function __construct($provider, $marketplaceAddress)
    {
        $this->provider = $provider;
		$this->marketplaceAddress = $marketplaceAddress;
    }

	protected function getContract($abiName) {
		$sweb3 = new SWeb3($this->provider);
		$marketplaceContractRawData = file_get_contents(plugin_dir_path(dirname(__FILE__)) . "contracts/abis/".$abiName.".json");
		$marketplaceABI = json_decode($marketplaceContractRawData, true)["abi"];
		return new SWeb3_contract($sweb3, $this->marketplaceAddress, json_encode($marketplaceABI));
	}

    /**
     * Throws an error if the RPC call fails, else just returns the response.
     *
     * @param $response
     * @return mixed
     * @throws \Exception
     * @since 3.2.0
     */
    private function throwError($response) {
        if (property_exists($response, 'error')) throw new \Exception($response->error->message);

        return $response;
    }
    /**
     * @throws \Exception
     */
    public function getPublicVars($varname, $data = [])
    {
        return $this->getContract('MarketplaceV3')->call($varname, $data);
    }

	/**
	 * @throws \Exception
	 */
	public function getOffers($marketplaceId, $address)
	{
		return $this->getContract('MarketplaceV3')->call("offers", [$marketplaceId, $address]);
	}

	/**
	 * @throws \Exception
	 */
	public function getWinner($key)
	{
		return $this->getContract('IEnglishAuctions')->call("getWinningBid", [$key]);
	}

    /**
     * @throws \Exception
     */
    public function getMarketplaceItem($itemId)
    {
        return $this->getContract('IDirectListings')->call("getListing", $itemId);
    }

    /**
     * @throws \Exception
     */
    public function getMarketplaceFeeInfo()
    {
        return $this->throwError($this->getContract('MarketplaceV3')->call("getPlatformFeeInfo"));
    }

    /**
     * @throws \Exception
     */
    public function getContractVersion()
    {
        return $this->throwError($this->getContract('MarketplaceV3')->call("contractVersion"));
    }

    /**
     * @throws \Exception
     */
    public function getOffer($offerId)
    {
        return $this->getContract('IOffers')->call("getOffer", [$offerId]);
    }

    /**
     * @throws \Exception
     */
    public function didTransactionSucceed($transaction)
    {
        $call = $this->sweb3->call("eth_getTransactionReceipt", [$transaction]);

        if (property_exists($call, "error")) {
            return false;
        }

        return str_replace("0x", "", $call->result->status) === "1";
    }
}
