<?php
/**
 * code
 *
 * @package   code
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Internals;

use NFT_Marketplace_Core\Engine\Base;

/**
 * Provides important variables for the frontend. (both at the user end and at admin end)
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class JsBridge extends Base
{
    /**
     * Initialize the class and get the plugin settings
     */
    public function initialize()
    {
        parent::initialize();

        add_action('admin_head', [$this, "provideVariables"]);
        add_action('wp_head', [$this, "provideVariables"]);

        add_action('admin_footer', [$this, "loadDev"]);
        add_action('wp_footer', [$this, "loadDev"]);
    }

    /**
     * Provide data for frontend
     * @return void
     */
    public function provideVariables()
    {
        $isLoggedInWithMetamask = function_exists("mtm_metamask_current_user_has_metamask") && is_user_logged_in() && mtm_metamask_current_user_has_metamask();
        $isLoggedInWithCoinbase = function_exists("cb_coinbase_current_user_has_coinbase") && is_user_logged_in() && cb_coinbase_current_user_has_coinbase();
        $isLoggedInWithWalletConnect = function_exists("mtwc_walletconnect_current_user_has_walletconnect") && is_user_logged_in() && mtwc_walletconnect_current_user_has_walletconnect();
        ?>
        <script type="text/javascript" id="nft-marketplace-core-vars">
            window.nftMarketplaceCore = {};
						window.nftMarketplaceCore.thirdwebClientId = "<?php echo isset(get_option('nft_marketplace_core_panel_thirdweb_api_tab')['nft_marketplace_core_panel_thirdweb_api_client_id']) ? get_option('nft_marketplace_core_panel_thirdweb_api_tab')['nft_marketplace_core_panel_thirdweb_api_client_id'] : '' ?>";
            window.nftMarketplaceCore.isLoggedInWithMetamask = <?php echo var_export($isLoggedInWithMetamask || $isLoggedInWithWalletConnect, true) ?>;
            window.nftMarketplaceCore.isLoggedInWithCoinbase = <?php echo var_export($isLoggedInWithCoinbase, true) ?>;
            window.nftMarketplaceCore.hasMultipleWalletsInstalled =  <?php echo var_export(function_exists("mtwc_walletconnect_current_user_has_walletconnect") && function_exists("mtm_metamask_current_user_has_metamask"), true) ?>;
            window.nftMarketplaceCore.apiLocation = "<?php echo get_rest_url(); ?>";
            window.nftMarketplaceCore.pluginLocation = "<?php echo plugin_dir_url(__DIR__); ?>";
            window.nftMarketplaceCore.nonce = "<?php echo wp_create_nonce('wp_rest'); ?>";
            window.nftMarketplaceCore.projectId = "<?php echo isset(get_option( 'mtwc_auth_option_name' )['project_id']) ? get_option( 'mtwc_auth_option_name' )['project_id'] : "";  ?>";
            window.nftMarketplaceCore.chains = "<?php echo isset(get_option( 'mtwc_auth_option_name' )['chains']) ? get_option( 'mtwc_auth_option_name' )['chains'] : "";  ?>";
        </script>
        <?php
    }

    /**
     * Returns all RPCs as a list.
     *
     * Used mostly for interacting with WalletConnect.
     * @TODO use for wallet switching.
     *
     * @return false|string
     * @since 2.0.0
     */
    public static function getRPCList()
    {
        $rpc_list = [];

        $terms = get_terms(array(
            'taxonomy' => 'nft_listing_blockchains',
            'hide_empty' => false,
        ));

        foreach ($terms as $term) {
            $rpc_url = get_term_meta($term->term_id, "nft_marketplace_core_taxonomy_blockchain_currency_rpc_url", true);
            $chainid = get_term_meta($term->term_id, "nft_marketplace_core_taxonomy_blockchain_currency_chainid", true);
            $rpc_list[hexdec($chainid)] = $rpc_url;
        }

        return json_encode($rpc_list);
    }

    /**
     * Load dev environment.
     * @return void
     */
    public function loadDev()
    {
        if (NFT_MARKETPLACE_CORE_IS_DEVMODE_ON) {
            $path = plugin_dir_path(dirname(__DIR__)) . "dev-do-not-upload/Vite.php";
            if (file_exists($path)) {
                require_once $path;
                $vite = new \Vite();
                echo $vite;
            }
        }
    }
}
