<?php

/**
 * NFT_Marketplace_Core
 *
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 */

namespace NFT_Marketplace_Core\Internals;

use NFT_Marketplace_Core\Engine\Base;
use NFT_Marketplace_Core\Internals\Helpers\VerifyConfig;

/**
 * Post Types and Taxonomies
 */
class PostTypes extends Base {

	/**
	 * Initialize the class.
	 *
	 * @return void
	 */
	public function initialize() { // phpcs:ignore
		parent::initialize();

		// WPBPGen{{#if libraries_johnbillion__extended-cpts}}
		\add_action( 'init', array( $this, 'load_cpts' ) );
		// {{/if}}
		\add_action( 'admin_menu', [$this, 'remove_submenu_item'], 999 );

        // WPBPGen{{#if frontend_cpt-search-support}}
		// \add_filter( 'pre_get_posts', array( $this, 'filter_search' ) );
		// {{/if}}

        require_once NFT_MARKETPLACE_CORE_PLUGIN_ROOT . 'internals/shortcodes/shortcodes.php';
    }

	// WPBPGen{{#if frontend_cpt-search-support}}
	/**
	 * Add support for custom CPT on the search box
	 *
	 * @param \WP_Query $query WP_Query.
	 * @since 2.0.0
	 * @return \WP_Query
	 */
	public function filter_search( \WP_Query $query ) {
		if ( $query->is_search && !\is_admin() ) {
			$post_types = $query->get( 'post_type' );

			if ( 'post' === $post_types ) {
				$post_types = array( $post_types );
				$query->set( 'post_type', \array_push( $post_types, array( 'demo' ) ) );
			}
		}

		return $query;
	}
	// {{/if}}

	// WPBPGen{{#if libraries_johnbillion__extended-cpts}}
	/**
	 * Load CPT and Taxonomies on WordPress
	 *
	 * @since 2.0.0
	 * @return void
	 */
	public function load_cpts() { //phpcs:ignore
		// Create Custom Post Type https://github.com/johnbillion/extended-cpts/wiki
        $hasBlockchains = !VerifyConfig::emptyBlockchains();

        \register_post_type(
				'nft-listing',
			array(
				'label' => esc_html__('NFT Listings', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
				'description' => '',
				'public' => true,
				'show_ui' => true,
				'show_in_menu' => true,
				'capability_type' => 'post',
				'hierarchical' => false,
				'publicly_queryable' => true,
				'rewrite' => array('slug' => get_option('nft_marketplace_core_panel_pages_tab')['nft_marketplace_core_panel_paths_nft'], 'with_front' => true),
				'query_var' => true,
				'menu_position' => '1',
				'menu_icon' => plugin_dir_url( __DIR__ ).'/backend/assets/images/nmc-logo.svg',
				'supports' => array('title', 'thumbnail', 'author'),
				'labels' => array(
					'name' => esc_html__('NFT Listings', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'singular_name' => esc_html__('NFT Listings', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'all_items' => esc_html__('NFT Listings', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'menu_name' => esc_html__('NFT Marketplace Core', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'add_new' => esc_html__('Add NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'add_new_item' => esc_html__('Import existing NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'edit' => esc_html__('Edit', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'edit_item' => esc_html__('Edit NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'new_item' => esc_html__('Import another NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'view' => esc_html__('View NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'view_item' => esc_html__('View NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'search_items' => esc_html__('Search NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'not_found' => esc_html__('No NFT Found', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'not_found_in_trash' => esc_html__('No NFT Found in Trash', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
					'parent' => esc_html__('Parent NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
				),
                'capabilities' => array(
                    'create_posts' => $hasBlockchains ? true : "do_not_allow", // Removes support for the "Add New" function ( use 'do_not_allow' instead of false for multisite set ups )
                ),
                'map_meta_cap' => $hasBlockchains, // Set to `false`, if users are not allowed to edit/delete existing posts

            )
		);

        $labels = array(
            'name' => esc_html_x('Blockchains', 'Taxonomy General Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'singular_name' => esc_html_x('Blockchain', 'Taxonomy Singular Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'menu_name' => esc_html__('Blockchains', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'all_items' => esc_html__('All Blockchains', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'parent_item' => esc_html__('Parent Item (leave empty)', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'parent_item_colon' => esc_html__('Parent Item (leave empty):', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'new_item_name' => esc_html__('New Item Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'add_new_item' => esc_html__('Add New Blockchain', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'edit_item' => esc_html__('Edit Blockchain', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'update_item' => esc_html__('Update Blockchain', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'view_item' => esc_html__('View Blockchains', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'separate_items_with_commas' => esc_html__('Separate items with commas', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'add_or_remove_items' => esc_html__('Add or remove items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'choose_from_most_used' => esc_html__('Choose from the most used', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'popular_items' => esc_html__('Popular Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'search_items' => esc_html__('Search Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'not_found' => esc_html__('Not Found', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
        );

        $args = array(
            'hierarchical' => true,
            'labels' => $labels,
            'show_ui' => true,
            'show_admin_column' => true,
            'show_in_nav_menus' => true,
            'query_var' => true,
            'rewrite' => false,
            'public' => true,
        );

        register_taxonomy('nft_listing_blockchains', array('nft-listing'), $args);

		// Create Custom Taxonomy https://github.com/johnbillion/extended-taxos
		$labels = array(
			'name' => esc_html_x('Collections', 'Taxonomy General Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'singular_name' => esc_html_x('Collections', 'Taxonomy Singular Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'menu_name' => esc_html__('Collections', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'all_items' => esc_html__('All Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'parent_item' => esc_html__('Parent Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'parent_item_colon' => esc_html__('Parent Item:', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'new_item_name' => esc_html__('New Item Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'add_new_item' => esc_html__('Add New Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'edit_item' => esc_html__('Edit Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'update_item' => esc_html__('Update Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'view_item' => esc_html__('View Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'separate_items_with_commas' => esc_html__('Separate items with commas', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'add_or_remove_items' => esc_html__('Add or remove items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'choose_from_most_used' => esc_html__('Choose from the most used', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'popular_items' => esc_html__('Popular Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'search_items' => esc_html__('Search Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'not_found' => esc_html__('Not Found', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
		);

		$args = array(
			'hierarchical' => true,
			'labels' => $labels,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'query_var' => true,
			'rewrite' => array('slug' => get_option('nft_marketplace_core_panel_pages_tab')['nft_marketplace_core_panel_paths_collection']),
			'public' => true,
		);

        if ($hasBlockchains) {
            register_taxonomy('nft-listing-collection', array('nft-listing'), $args);
        }

        // Create Custom Taxonomy https://github.com/johnbillion/extended-taxos
        $labels = array(
            'name' => esc_html_x('Custom Currency', 'Taxonomy General Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'singular_name' => esc_html_x('Currency', 'Taxonomy Singular Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'menu_name' => esc_html__('Currencies', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'all_items' => esc_html__('All Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'parent_item' => esc_html__('Parent Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'parent_item_colon' => esc_html__('Parent Item:', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'new_item_name' => esc_html__('New Item Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'add_new_item' => esc_html__('Add New Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'edit_item' => esc_html__('Edit Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'update_item' => esc_html__('Update Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'view_item' => esc_html__('View Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'separate_items_with_commas' => esc_html__('Separate items with commas', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'add_or_remove_items' => esc_html__('Add or remove items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'choose_from_most_used' => esc_html__('Choose from the most used', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'popular_items' => esc_html__('Popular Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'search_items' => esc_html__('Search Items', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
            'not_found' => esc_html__('Not Found', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
        );

        $args = array(
            'hierarchical' => true,
            'labels' => $labels,
            'show_ui' => true,
            'show_admin_column' => true,
            'show_in_nav_menus' => true,
            'query_var' => true,
            'rewrite' => false,
            'public' => false,
        );

        if ($hasBlockchains) {
            register_taxonomy('nft-listing-currency', array('nft-listing'), $args);
        }

		$labels = array(
			'name' => esc_html_x('Categories', 'Taxonomy General Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'singular_name' => esc_html_x('Category', 'Taxonomy Singular Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'menu_name' => esc_html__('Categories', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'all_items' => esc_html__('All Categories', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'parent_item' => esc_html__('Parent Item (leave empty)', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'parent_item_colon' => esc_html__('Parent Item (leave empty):', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'new_item_name' => esc_html__('New Category Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'add_new_item' => esc_html__('Add Category Item', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'edit_item' => esc_html__('Edit Category', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'update_item' => esc_html__('Update Category', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'view_item' => esc_html__('View Category', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'separate_items_with_commas' => esc_html__('Separate Categories with commas', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'add_or_remove_items' => esc_html__('Add or remove Categories', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'choose_from_most_used' => esc_html__('Choose from the most used', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'popular_items' => esc_html__('Popular Categories', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'search_items' => esc_html__('Search Categories', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
			'not_found' => esc_html__('Not Found', NFT_MARKETPLACE_CORE_TEXTDOMAIN),
		);

		$args = array(
			'hierarchical' => true,
			'labels' => $labels,
			'show_ui' => true,
			'show_admin_column' => true,
			'show_in_nav_menus' => true,
			'query_var' => true,
            'rewrite' => array('slug' => get_option('nft_marketplace_core_panel_pages_tab')['nft_marketplace_core_panel_paths_categories']),
			'public' => true,
		);

        if ($hasBlockchains) {
            register_taxonomy('nft-listing-category', array('nft-listing'), $args);
        }
    }
	// {{/if}}

	function remove_submenu_item() {
		// Replace 'toplevel_page_slug' with the slug of the top-level menu item.
		// Replace 'submenu_page_slug' with the slug of the submenu item you want to remove.
		remove_submenu_page( 'edit.php?post_type=nft-listing', 'post-new.php?post_type=nft-listing' );
	}
}
