<?php

namespace NFT_Marketplace_Core\Internals\Helpers;

use SWeb3\SWeb3;
use SWeb3\SWeb3_Contract;

/**
 * Logs the provenience of the NFT.
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright All rights reserved for ModelTheme
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class Provenience
{
    /**
     * Save the log (provenience) to database.
     * @param $postId
     * @param $type
     * @param $args
     * @return void
     * @since 2.0.0
     */
    public static function save($postId, $type, $args)
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'nft_marketplace_core_logs';
        $table_name_values = $wpdb->prefix . 'nft_marketplace_core_logs_values';

        $wpdb->insert($table_name, [
            "nft_id" => $postId,
            "log_type" => $type
        ]);

        $logId = $wpdb->insert_id;

        foreach ($args as $key => $value) {
            $wpdb->insert($table_name_values, [
                "log_id" => $logId,
                "log_value" => $value,
                "log_string" => $key
            ]);
        }
    }

    /**
     * Read the Provenience from database.
     * @param $nft_id
     * @return string[]
     * @since 2.0.0
     */
    public static function read($nft_id)
    {
        global $wpdb;
        $table_name = $wpdb->prefix . 'nft_marketplace_core_logs';
        $table_name_values = $wpdb->prefix . 'nft_marketplace_core_logs_values';
        $logs = $wpdb->get_results("SELECT * FROM $table_name WHERE `nft_id` = $nft_id;");

        $logsFormatted = [];

        foreach ($logs as $log) {
            $logId = $log->id;
            $log_values = $wpdb->get_results("SELECT * FROM $table_name_values WHERE `log_id` = $logId");

            $text = "";

            if ($log->log_type == 1) {
                $text = esc_html__("The NFT was created by %username%.", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
            } else if ($log->log_type == 2) {
                $text = esc_html__("The NFT was listed by %username% for %price% %currency%.", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
            } else if ($log->log_type == 3) {
                $text = esc_html__("The NFT was sold to %username% for %price% %currency%.", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
            } else if ($log->log_type == 4) {
                $text = esc_html__("The NFT was relisted by %username% for %price% %currency%.", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
            } else if ($log->log_type == 5) {
                $text = esc_html__("The Listing was cancelled by %username%.", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
            }

            $logMessageData = call_user_func_array('array_merge', array_map(function ($log) {
                return ["%".$log->log_string."%" => $log->log_value];
            }, $log_values));

            $logsFormatted[] = [
                "log_type" => $log->log_type,
                "log_date" => $log->log_date,
                "log_message" => str_replace(array_keys($logMessageData), array_values($logMessageData), $text),
                "log_extra_data" => $logMessageData,
            ];
        }

        return $logsFormatted;
    }
}
