<?php
/**
 * @package   NFT_Marketplace_Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, ModelTheme, support@modeltheme.com
 * @license   GPL v3
 * @link      https://modeltheme.com
 *
 * Plugin Name:     Enefti - NFT Marketplace Core
 * Plugin URI:      https://codecanyon.net/item/enefti-nft-marketplace-core/37972199
 * Description:     Creating a full NFT Marketplace in WordPress has never been this easy.
 * Version:         5.0.4
 * Author:          20script
 * Author URI:      https://www.20script.ir
 * Text Domain:     nft-marketplace-core
 * License:         GPL v3
 * License URI:     http://www.gnu.org/licenses/gpl-3.0.txt
 * Domain Path:     /languages
 * Requires PHP:    7.0
 * WordPress-Plugin-Boilerplate-Powered: v3.3.0
 */

// If this file is called directly, abort.
use Micropackage\Requirements\Requirements;
use NFT_Marketplace_Core\Backend\ActDeact;
use NFT_Marketplace_Core\Engine\Initialize;

if (!defined('ABSPATH')) {
    die('We\'re sorry, but you can not directly access this file.');
}

define('NFT_MARKETPLACE_CORE_VERSION', '5.0.1');
define('NFT_MARKETPLACE_CORE_TEXTDOMAIN', "nft-marketplace-core");
define('NFT_MARKETPLACE_CORE_NAME', 'NFT Marketplace Core');
define('NFT_MARKETPLACE_CORE_PLUGIN_ROOT', plugin_dir_path(__FILE__));
define('NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION', __FILE__);
define('NFT_MARKETPLACE_CORE_PLUGIN_URL', plugin_dir_url(__FILE__));
define('NFT_MARKETPLACE_CORE_PLUGIN_LOCATION', str_replace(WP_PLUGIN_DIR . "/", "", __DIR__));
define('NFT_MARKETPLACE_CORE_MIN_PHP_VERSION', '7.0');
define('NFT_MARKETPLACE_CORE_WP_VERSION', '5.3');
define('NFT_MARKETPLACE_CORE_IS_DEVMODE_ON', FALSE);

define('NFT_MARKETPLACE_CORE_CODECANYON_ID', '37972199');

// If the theme is installed and this is not the essentials bundle try activation with the code
if (function_exists("modeltheme_framework") && NFT_MARKETPLACE_CORE_CODECANYON_ID === '37972199') {
    define('NFT_MARKETPLACE_CORE_CODECANYON_ID', '36258540');
}


// WPBPGen{{#if language-files}}
add_action(
    'init',
    static function () {
        load_plugin_textdomain(NFT_MARKETPLACE_CORE_TEXTDOMAIN, false, dirname(plugin_basename(__FILE__)) . '/languages');
    }
);

// {{/if}}
if (version_compare(PHP_VERSION, NFT_MARKETPLACE_CORE_MIN_PHP_VERSION, '<=')) {
    add_action(
        'admin_init',
        static function () {
            deactivate_plugins(plugin_basename(__FILE__));
        }
    );
    add_action(
        'admin_notices',
        static function () {
            echo wp_kses_post(
                sprintf(
                    '<div class="notice notice-error"><p>%s</p></div>',
                    __('"NFT Marketplace Core" requires PHP 7.0 or newer.', NFT_MARKETPLACE_CORE_TEXTDOMAIN)
                )
            );
        }
    );

    // Return early to prevent loading the plugin.
    return;
}

$nft_marketplace_core_libraries = require NFT_MARKETPLACE_CORE_PLUGIN_ROOT . 'vendor/autoload.php'; //phpcs:ignore

require_once NFT_MARKETPLACE_CORE_PLUGIN_ROOT . 'functions/functions.php';
// WPBPGen{{#if libraries_wpbp__debug}}
require_once NFT_MARKETPLACE_CORE_PLUGIN_ROOT . 'functions/debug.php';
// {{/if}}

// WPBPGen{{#if libraries_micropackage__requirements}}
$requirements = new Requirements(
    'NFT Marketplace Core',
    array(
        'php' => NFT_MARKETPLACE_CORE_MIN_PHP_VERSION,
        'php_extensions' => array('mbstring'),
        'wp' => NFT_MARKETPLACE_CORE_WP_VERSION,
    )
);

if (!$requirements->satisfied() && !NFT_MARKETPLACE_CORE_IS_DEVMODE_ON) {
    $requirements->print_notice();
    return;
}
// {{/if}}

if (!wp_installing()) {
    register_activation_hook(NFT_MARKETPLACE_CORE_TEXTDOMAIN . '/' . NFT_MARKETPLACE_CORE_TEXTDOMAIN . '.php', array(new ActDeact, 'activate'));
    register_deactivation_hook(NFT_MARKETPLACE_CORE_TEXTDOMAIN . '/' . NFT_MARKETPLACE_CORE_TEXTDOMAIN . '.php', array(new ActDeact, 'deactivate'));
    add_action(
        'plugins_loaded',
        static function () use ($nft_marketplace_core_libraries) {
            new Initialize($nft_marketplace_core_libraries);
        }
    );
}

// Display a notice when upgrading the plugin
add_filter("install_plugin_overwrite_comparison", function ($table, $args) {
    if (strtolower($args["Author"]) === "modeltheme" || strtolower($args["AuthorName"]) === "modeltheme") {
        wpdesk_wp_notice("<b>" . esc_html__("READ BEFORE PROCEEDING AS IT MIGHT SAVE YOU A LOT OF TROUBLE:") . "</b><br/>" . esc_html__("Before upgrading the plugin please make sure you have backed up your current installation or even better try the plugin on a test version of your website to make sure that everything will go smoothly! ", NFT_MARKETPLACE_CORE_TEXTDOMAIN), 'error');
    }
}, 10, 2);
