<?php
namespace NFT_Marketplace_Core\Rest;

use NFT_Marketplace_Core\Engine\Base;

/**
 *
 * Handles contract actions. Admin side only
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class Contract extends Base {

    /**
     * Initialize the class.
     *
     * @return void
     */
    public function initialize() {
        parent::initialize();

        \add_action( 'rest_api_init', array( $this, 'register_routes' ) );
    }

    public function register_routes() {
        register_rest_route(NFT_MARKETPLACE_CORE_TEXTDOMAIN, '/sync-contract', array(
            'methods' => 'POST',
            'callback' => [$this, 'sync'],
            'permission_callback' => function ( $request ) {
                return is_user_logged_in() && current_user_can('administrator') && wp_verify_nonce($request->get_header("X-WP-Nonce"), "wp_rest");
            },
        ));

        register_rest_route(NFT_MARKETPLACE_CORE_TEXTDOMAIN, '/delete-contract', array(
            'methods' => 'POST',
            'callback' => [$this, 'delete'],
            'permission_callback' => function ( $request ) {
                return is_user_logged_in() && current_user_can('administrator') && wp_verify_nonce($request->get_header("X-WP-Nonce"), "wp_rest");
            },
        ));
    }

    public function sync( $request) {
        global $wpdb;

        $price = $request->get_param("price");
        $blockchain_id = $request->get_param("blockchain_id");

        if(!is_numeric($price) && !is_numeric($blockchain_id)) {
            return new \WP_REST_Response(array( 'message' => 'Something went wrong' ), 401);
        }

        $result = $wpdb->update($wpdb->prefix."nft_marketplace_core_contracts", [
            "listing_price" => $price
        ], [
            "id" => $blockchain_id
        ]);


        return new \WP_REST_Response(array( 'message' => esc_html__('Contract Updated!', NFT_MARKETPLACE_CORE_TEXTDOMAIN) ), 201);
    }

    public function delete( $request) {
        global $wpdb;

        $blockchain_id = $request->get_param("blockchain_id");


        if(!is_numeric($blockchain_id) && !is_null(get_term($blockchain_id))) {
            return new \WP_REST_Response(array( 'message' => 'Something went wrong' ), 401);
        }

        $wpdb->delete($wpdb->prefix."nft_marketplace_core_contracts",[
            "taxonomy_blockchain_id" => $blockchain_id
        ]);


        return new \WP_REST_Response(array( 'message' => esc_html__('Contract Deleted!', NFT_MARKETPLACE_CORE_TEXTDOMAIN) ), 201);
    }
}
