<?php

namespace NFT_Marketplace_Core\Rest;

use Exception;
use NFT_Marketplace_Core\Contracts\Factory;
use NFT_Marketplace_Core\Engine\Base;
use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;
use NFT_Marketplace_Core\Internals\Metas\BlockchainMeta;
use NFT_Marketplace_Core\Internals\Metas\NFTMeta;

/**
 * Any other API endpoint that cannot be used inside other classes
 *
 * @package   NFT Marketplace Core
 * @author    ModelTheme <support@modeltheme.com>
 * @copyright Copyright (C) 2012-2022, Modeltheme, support@modeltheme.com
 * @license   GPL-3.0
 * @link      https://modeltheme.com
 */
class Misc extends Base
{

	/**
	 * Initialize the class.
	 *
	 * @return void
	 */
	public function initialize()
	{
		parent::initialize();

		\add_action('rest_api_init', array($this, 'register_routes'));
	}

	public function register_routes()
	{
		register_rest_route(NFT_MARKETPLACE_CORE_TEXTDOMAIN, '/refresh-metadata', array(
			'methods' => 'POST',
			'callback' => [$this, 'refreshMetadata'],
			'permission_callback' => function ($request) {
				return current_user_can("administrator");
			},
		));
	}

	public function refreshMetadata($request): \WP_REST_Response
	{
		$postId = $request->get_param("nftId");
		$tokenId = $request->get_param("tokenId");

		if (!$postId || 'publish' !== get_post_status($postId)) {
			return new \WP_REST_Response(["message" => esc_html__("Could not find the NFT", NFT_MARKETPLACE_CORE_TEXTDOMAIN)], 400);
		}

		try {
			$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postId, 'nft_listing_blockchains');
			$termId = $nft_marketplace_core_nft_listing_blockchains_term[0]->term_id;
			$address = get_post_meta($postId, NFTMeta::address, true);
			$provider = get_term_meta($termId, BlockchainMeta::rpc, true);
			$type = Helper::getUnknownContractType($address, $provider);
			Marketplace::runQueue([
				[
					"post_id" => $postId,
					"address" => $address,
					"token" => $tokenId,
					"blockchain_id" => $termId,
					"contract_type" => $type,
					"is_imported" => 0,
					"added_at" => current_time('mysql')
				]
			], $termId);

		} catch (Exception $e) {
			return new \WP_REST_Response(["message" => $e->getMessage()], 400);
		}

		return new \WP_REST_Response(["message" => esc_html__("Metadata Updated!", NFT_MARKETPLACE_CORE_TEXTDOMAIN)], 200);
	}
}
