<?php
/**
 * Template Name: Vendor Panel for Managing NFTs.
 *
 * @package    NFT Marketplace Core
 * @subpackage NFT Marketplace Core/public
 * @author     ModelTheme <support@modeltheme.com>
 */

wp_enqueue_style('nft-marketplace-core-nft-manager-v1', plugin_dir_url(dirname(__FILE__)).'/assets/css/versions/nft-manager-v1.css'  );

if(!is_user_logged_in()) {
    wp_redirect( get_permalink( get_page_by_path( get_option('nft_marketplace_core_panel_pages_tab')['nft_marketplace_core_panel_pages_connect_your_wallet'] ) ) );
    exit;
}

if (isset($_GET['manage-contract'])) {
    require_once plugin_dir_path(__FILE__) . "dashboard/contracts/manage-contract.php";
    exit;
}

if (isset($_GET['manage-collection']) || isset($_GET['create-collection'])) {
    require_once plugin_dir_path(__FILE__) . "dashboard/collections/manage-collection.php";
    exit;
}

$current_user = wp_get_current_user();
$author_edit_link = get_home_url().'/'.get_option('nft_marketplace_core_panel_pages_tab')['nft_marketplace_core_panel_pages_dashboard'].'?tab=5';
$author_link = home_url($wp->request);

//Update Form
do_shortcode('[nft_marketplace_core_update_author_form_shortcode]');
$nft_marketplace_core_banner_img = get_user_meta($current_user->ID,'nft_marketplace_core_banner_img',true);
$getUserUrl = get_avatar_url ($current_user->ID);

get_header();

/**
 * Plugin Breadcrumbs
 * since version 1.0
 */
do_action('nft_marketplace_core_before_main_content', "", "NFTs Manager");
$logoutUrl = wp_logout_url();

?>
<div id="nft-marketplace-core-manager-panel" class="content-area">
    <main id="main" class="site-main " role="main">
        <div class="container blog-posts single-nft">
            <section class="tabs-wrapper">
                <div class="tabs-container">
                    <div class="tabs-block">
                        <div id="tabs-section" class="tabs">
                            <div class="col-lg-2 col-md-2f col-sm-12 col-12 p-0 manager-sidebar">
                                <div class="sidebar-top-content">
                                    <div class="nft-logo">
                                        <img class="enefti-logo" style="width:75px;height:75px" src="<?php echo esc_url(plugin_dir_url( __DIR__ ).'/backend/assets/images/nmc-logo.svg'); ?>" alt="Marketplace Test">
                                    </div>
                                    <div class="sidebar-items d-flex flex-column">
                                        <ul class="tab-head">
                                            <li class=" <?php ((isset($_GET["tab"]) && $_GET["tab"] === "1") || !isset($_GET["tab"])) ? esc_attr_e('active') : '' ; ?>">
                                                <a href="#tab-1" class="tab-link ">
                                                    <span class="tab-label"><i class="fas fa-user"></i><?php esc_html_e("Dashboard",NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></span>
                                                </a>
                                            </li>
                                            <li class=" <?php (isset($_GET["tab"]) && $_GET["tab"] === "2") ? esc_attr_e('active') : '' ; ?>">
                                                <a href="#tab-2" class="tab-link">
                                                    <span class="tab-label"><i class="fas fa-box"></i><?php esc_html_e("My NFTs",NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></span>
                                                </a>
                                            </li>
                                            <li class=" <?php (isset($_GET["tab"]) && $_GET["tab"] === "3") ? esc_attr_e('active') : '' ; ?>">
                                                <a href="#tab-3" class="tab-link">
                                                    <span class="tab-label"><i class="fas fa-file-contract"></i><?php esc_html_e("My Contracts",NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></span>
                                                </a>
                                            </li>
                                            <li class=" <?php (isset($_GET["tab"]) && $_GET["tab"] === "4") ? esc_attr_e('active') : '' ; ?>">
                                                <a href="#tab-4" class="tab-link">
                                                    <span class="tab-label"><i class="fas fa-layer-group"></i><?php esc_html_e("My Collections",NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></span>
                                                </a>
                                            </li>
                                            <li class=" <?php (isset($_GET["tab"]) && $_GET["tab"] === "5") ? esc_attr_e('active') : '' ; ?>">
                                                <a href="#tab-5" class="tab-link">
                                                    <span class="tab-label"><i class="fas fa-wrench"></i><?php esc_html_e("Account Settings",NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></span>
                                                </a>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                                <div class="nft-sidebar-btn-group d-flex flex-column">
                                    <div class="logout-btn">
                                        <a href="<?php echo esc_url($logoutUrl); ?>">
                                            <span class="tab-label"><i class="fas fa-sign-out-alt"></i><?php esc_html_e("Logout",NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></span>
                                        </a>
                                    </div>
                                </div>

                            </div>
                            <div class="col-lg-10 col-md-10 col-sm-12 col-12 nft-manager-content">
                                <section id="tab-1"  class="tab-body entry-content active active-content">
                                    <?php
                                        if (!isset($_GET["tab"]) || $_GET["tab"] === "1") {
                                    ?>
                                    <div class="nft-account-section">
                                        <div class="nft-account-info d-flex justify-content-between">
                                            <div>

                                            </div>

                                            <div class="nft-author-group d-flex align-items-center">
                                                <div class="nft-author-profile d-flex align-items-center">
                                                    <a href="<?php echo esc_url(get_the_permalink());?>" class="nft-author-image">
                                                        <img src="<?php echo get_avatar_url($current_user->ID);?>">
                                                    </a>
                                                    <h3><?php echo esc_html( $current_user->display_name );?></h3>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="nft-manage row">
                                            <div class="nft-my-nfts d-flex justify-content-between align-items-center">
                                                <h2 class="nft-manager-title"><?php esc_html_e("My NFTs", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h2>
                                                <a class="nft-manage-extend" href="<?php echo esc_url( get_author_posts_url(get_current_user_id())); ?>"><?php esc_html_e("See More", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></a>
                                            </div>

                                            <?php
                                            $nfts_query_arg = array(
                                                'post_type' => 'nft-listing',
                                                'posts_per_page' => 4,
												'paged' => get_query_var('paged') ? (int)get_query_var('paged') : 1,
                                                'author__in' => array(get_current_user_id()),
                                            );
                                            $nfts_query = new WP_Query($nfts_query_arg);

                                            if( $nfts_query->have_posts() ) : ?>
                                                <?php while ( $nfts_query->have_posts() ) : $nfts_query->the_post(); ?>
                                                    <article id="post-<?php the_ID(); ?>" class="nft-listing col-md-3">
                                                        <?php do_action('nft_marketplace_core_author_listing_query'); ?>
                                                    </article>
                                                <?php endwhile; ?>
                                                <?php wp_reset_postdata(); ?>

                                                <div class="clearfix"></div>

                                                <?php do_action('nft_marketplace_core_author_after_grid'); ?>

                                            <?php else : ?>
                                                <strong><?php echo esc_html__('There are no NFT Listings!',NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></strong>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                    <?php } ?>
                                </section>

                                <section id="tab-2" class="tab-body entry-content active active-content">
                                    <?php
                                        if (isset($_GET["tab"]) && $_GET["tab"] === "2")
                                            require_once plugin_dir_path(__FILE__) . "dashboard/tab-nfts.php";
                                    ?>
                                </section>

                                <section id="tab-3" class="tab-body entry-content active active-content">
                                    <?php
                                        if (isset($_GET["tab"]) && $_GET["tab"] === "3")
                                            require_once plugin_dir_path(__FILE__) . "dashboard/tab-contracts.php";
                                    ?>
                                </section>

                                <section id="tab-4" class="tab-body entry-content active active-content">
                                    <?php
                                        if (isset($_GET["tab"]) && $_GET["tab"] === "4")
                                            require_once plugin_dir_path(__FILE__) . "dashboard/tab-collections.php";
                                    ?>
                                </section>

                                <section id="tab-5" class="tab-body entry-content active active-content">
                                    <?php if (isset($_GET["tab"]) && $_GET["tab"] === "5")
                                        require_once plugin_dir_path(__FILE__) . "dashboard/tab-account.php";
                                    ?>
                                </section>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
        </div>
    </main>
</div>


<?php
get_footer();
?>

<script>

    //
    // Tabs Toggler
    //

    ( function( $ ) {
        // Variables
        const $tabLink = $( '#tabs-section .tab-link' );
        const $tabBody = $( '#tabs-section .tab-body' );
        let timerOpacity;

        const url =  window.location.protocol + "//" + window.location.host + window.location.pathname ;
        const hash = window.location.href.split('#').pop();

        const setActive = (element) => {
            // Toggle Class Logic
            // Remove Active Classes
            $tabLink.removeClass( 'active ' );
            $tabBody.removeClass( 'active ' );
            $tabBody.removeClass( 'active-content' );
            // Add Active Classes
            $( element ).addClass( 'active' );
            $( $( element ).attr( 'href' ) ).addClass( 'active' );


            // Opacity Transition Class
            timerOpacity = setTimeout( () => {
                $( $( element ).attr( 'href' ) ).addClass( 'active-content' );
            }, 50 );
        }

        if (hash !== window.location.href) {
            const els = document.querySelectorAll("a[href='"+ "?tab="+ hash +"']");
            setActive(els[0]);
        }



        // Toggle Class
        const init = () => {
            // Menu Click
            $tabLink.off( 'click' ).on( 'click', function( e ) {
                // Prevent Default
                e.preventDefault();
                e.stopPropagation();
                // Clear Timers
                window.clearTimeout( timerOpacity );

                setActive(this)

                if (history.pushState) {
                    const newUrl = url + '?tab=' +  $( $( this ).attr( 'href' ) )[0].id;
                    window.location = newUrl.replace("tab-", "");
                }
            } );
        };

        // Document Ready
        $( function() {
            init();
        } );
    }( jQuery ) );
</script>



