<?php
/**
 * The template for single NFT Listing pages.
 */

use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;

// Redirect to 404 if user is not author
if(get_current_user_id() !== (int) get_post(get_the_ID())->post_author) {
	global $wp_query;
	$wp_query->set_404();
	status_header(404);
	get_template_part(404);
	exit();
}

$postID = get_the_ID();
$additionalData = null;
$contractHelper = Helper::contractHelperFromPostId($postID, $additionalData);

do_action("nft_marketplace_core_list_nft", $postID);

if (isset($_POST["nft_marketplace_core_nft_marketplace_id"]) && is_numeric($_POST["nft_marketplace_core_nft_marketplace_id"])) {
	Marketplace::makeListing($postID, $_POST["nft_marketplace_core_nft_marketplace_id"]);
	exit();
}

get_header();
$nft_marketplace_core_nft_listing_price = get_post_meta($postID, 'nft_marketplace_core_nft_listing_price_meta', true);
$nft_marketplace_core_nft_listing_token_id = get_post_meta($postID, 'nft_marketplace_core_nft_listing_token_id', true);
$nft_marketplace_core_nft_listing_address = get_post_meta($postID, 'nft_marketplace_core_nft_listing_address', true);
$nft_marketplace_core_nft_marketplace_id = get_post_meta($postID, 'nft_marketplace_core_nft_marketplace_id', true);

$nft_marketplace_core_nft_listing_start_time = get_post_meta($postID, 'nft_marketplace_core_nft_listing_start_time', true);
$hasItemLeftToSell = get_post_meta($postID, "nft_marketplace_core_nft_listing_quantity", true) > 0;
$listingNotExpired = get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true) > time();
$isItemOnSale = $hasItemLeftToSell && $listingNotExpired;
wp_enqueue_style('nft-marketplace-core-list-nft-v1', plugin_dir_url(NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION).'/assets/css/versions/list-nft-v1.css');
?>
	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">
			<div class="high-padding">
				<div class="container blog-posts single-nft">
					<div class="row">
						<h2 itemprop="name"
							class="nft_title entry-title"><?php echo esc_html__("List your ", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . esc_html(get_the_title()) . esc_html__(" for sale now!", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h2>
						<br/>
						<div class="col-md-8 main-content row">
							<?php
							if ($isItemOnSale) {
								esc_html_e("NFT is listed successfully!", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
								?>
								<br/>
								<a href="<?php echo get_permalink(get_the_ID()); ?>"
								   class="button-primary single_nft_button button alt"><?php esc_html_e('View Your NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></a>
								<?php
							} else { ?>
								<?php do_action("nft_marketplace_core_list_nft_before_form", $nft_marketplace_core_nft_listing_token_id,$nft_marketplace_core_nft_listing_address, $additionalData); ?>
								<form id="nft-marketplace-core-list-for-sale" method="post"
									  data-tokenid="<?php echo esc_attr($nft_marketplace_core_nft_listing_token_id); ?>"
									  data-address="<?php echo esc_attr($nft_marketplace_core_nft_listing_address); ?>"
									  data-market-address="<?php echo esc_attr($additionalData["marketplace_address"]); ?>"
									<?php echo NFT_Marketplace_Core\Internals\Helpers\BlockchainDatasetBuilder::switchNetwork($additionalData["term_id"]) ?>
									  class="form-field form-required term-slug-wrap">
									<div class="form-field form-required term-slug-wrap">
										<label for="nft_marketplace_core_nft_listing_currency_price"
										><?php esc_html_e("Price:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><span
												style="color: red"> *</span></label><br>
										<input value="0.01" id="nft_marketplace_core_nft_listing_currency_price"
											   name="nft_marketplace_core_nft_listing_currency_price" type="number"
											   step="0.0005"
											   required/>
										<p class="description"><?php esc_html_e("How much the asset will be sold for.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
									</div>

									<div class="form-field form-required term-slug-wrap">
										<label for="nft_marketplace_core_nft_listing_timestamp"
										><?php esc_html_e("Start Timestamp:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></label><br>
										<input value="" id="nft_marketplace_core_nft_listing_timestamp"
											   name="nft_marketplace_core_nft_listing_timestamp" type="date"/>
										<p class="description"><?php esc_html_e("When should the listing open up for offers.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
									</div>

									<div class="form-field form-required term-slug-wrap">
										<label for="nft_marketplace_core_nft_listing_duration"
										><?php esc_html_e("Listing Duration:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
											<span style="color: red">*</span> </label><br>
										<input value="" id="nft_marketplace_core_nft_listing_duration"
											   name="nft_marketplace_core_nft_listing_duration" type="number" required/>
										<p class="description"><?php esc_html_e("How long the listing will be open for. (in minutes)", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
									</div>

									<div class="form-field form-required term-slug-wrap">
										<label for="nft_marketplace_core_nft_listing_quantity"
										><?php esc_html_e("Quantity:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
											<span
												class="description"><?php esc_html_e("(For ERC721s, this value will always be 1)", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
										</label><br>
										<input value="1" id="nft_marketplace_core_nft_listing_quantity"
											   name="nft_marketplace_core_nft_listing_quantity" type="number"/>
										<p class="description"><?php esc_html_e("The quantity of tokens to include in the listing. For example: if the quantity = 10 and the reserve price = 1, then the buyout price is 10 coins.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></p>
									</div>

									<div class="form-field form-required term-slug-wrap">
										<label for="nft_marketplace_core_nft_listing_quantity">
											<?php esc_html_e("Currency:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										</label><br/>
										<?php

										$terms = get_terms([
											'taxonomy' => "nft-listing-currency",
											'hide_empty' => false,
											'meta_query' => array(
												array(
													'key'       => 'nft_marketplace_core_taxonomy_currency_blockchain',
													'value'     => $additionalData["term_id"],
													'compare'   => '='
												)
											)
										]);

										?>
										<select name="nft_marketplace_core_nft_listing_currency" id="nft_marketplace_core_nft_listing_currency" class="postform">
											<option value="native"><?php esc_html_e($additionalData["currency_symbol"]) ?></option>
											<?php foreach ($terms as $term) { ?>
												<option value="<?php esc_attr_e(get_term_meta($term->term_id, "nft_marketplace_core_taxonomy_currency_contract",true)); ?>"><?php esc_html_e($term->name); ?></option>
											<?php } ?>
										</select>
										<p class="description"><?php esc_html_e("The currency you want to sell this NFT with.",NFT_MARKETPLACE_CORE_TEXTDOMAIN);?></p>
									</div>
									<div style="color: red">
										<i style="margin-right: 3px" class="fas fa-exclamation-circle"></i>
										<?php esc_html_e("When someone purchases your NFT there will be a marketplace fee of", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										<b id="nft-marketplace-core-fee">
											<?php
											echo $additionalData["marketplace_fee"] . "%"
											?>
										</b>
										<?php esc_html_e("off the price you set.", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
									</div>
									<br/>
									<button name="submit-cmb"
											type="submit"
											class="listing-submit-btn">
										<?php esc_html_e('List Now', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>
								</form>
							<?php } ?>
						</div>
						<div class="col-md-4">
							<div class="enefti-listing-img">
								<?php echo NFT_Marketplace_Core\Internals\Helpers\Assets::getNFTDisplayAsset(get_the_ID()); ?>
								<table class="nft-listing-table">
									<tbody>
									<tr>
										<th>
											<?php esc_html_e('Service Fee', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										</th>
										<th id="nft-marketplace-core-table-fee">
											<?php echo $additionalData["marketplace_fee"] . "%"; ?>
										</th>
									</tr>
									<tr>
										<th>
											<?php esc_html_e('Your Cut', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										</th>
										<th id="nft-marketplace-core-your-cut">
											<?php esc_html_e('-', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										</th>
									</tr>
									<tr>
										<th>
											<?php esc_html_e('Available to purchase after', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										</th>
										<th id="nft-marketplace-core-available-purchase">
											<?php esc_html_e('Immediately after listing.', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
										</th>
									</tr>
									</tbody>
								</table>
							</div>
						</div>
					</div>
				</div>
			</div>
		</main>
	</div>
<?php

get_footer();
?>
