<?php
/**
 * The template for single NFT Listing pages.
 */

use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;

$postID = get_the_ID();

// Redirect to 404 if user is not author
if(get_current_user_id() !== (int) get_post(get_the_ID())->post_author) {
    global $wp_query;
    $wp_query->set_404();
    status_header( 404 );
    get_template_part( 404 ); exit();
}


$contractHelper = Helper::contractHelperFromPostId($postID, $additionalData);

global $wpdb;

/**
 * Define single NFT price,symbol,regular price
 */
$nft_marketplace_core_nft_listing_token_id = get_post_meta($postID, 'nft_marketplace_core_nft_listing_token_id', true);
$nft_marketplace_core_nft_listing_address = get_post_meta($postID, 'nft_marketplace_core_nft_listing_address', true);
$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postID, 'nft_listing_blockchains');
$nft_marketplace_core_nft_listing_price = get_post_meta($postID, 'nft_marketplace_core_nft_listing_currency_price', true);
$nft_marketplace_core_nft_marketplace_id = get_post_meta($postID, 'nft_marketplace_core_nft_marketplace_id', true);

/**
 * Main Content:Start of Page
 */
get_header();

/**
 * Main Content: Breadcrumbs
 */
do_action('nft_marketplace_core_before_main_content');

$table = $wpdb->prefix . "nft_marketplace_core_offers";

if (!is_numeric($_GET["offer-list"]) && 'publish' !== get_post_status($_GET["offer-list"])) {
    global $wp_query;
    $wp_query->set_404();
    status_header(404);
    get_template_part(404);
    exit();
}

$offers = $wpdb->prepare("SELECT * FROM $table WHERE nft_id = %s", ["nft_id" => $_GET["offer-list"]]);
$results = $wpdb->get_results($offers);

?>
<div id="primary" class="content-area">
    <main id="main" class="site-main" role="main">
        <div class="high-padding">
            <div class="container blog-posts single-nft">
                <div class="row">
                    <div class="col-md-12 main-content row">
                        <table>
                            <tr>
                                <th><?php esc_html_e("ID", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                                <th><?php esc_html_e("Offeror", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                                <th><?php esc_html_e("Quantity", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                                <th><?php esc_html_e("Offered Price", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                                <th><?php esc_html_e("Expiration Time", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                                <th><?php esc_html_e("Expired", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                                <th><?php esc_html_e("Actions", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></th>
                            </tr>
                            <?php foreach ($results as $result) {
                                $cannotExpire = $result->expirationTimestamp === "0000-00-00 00:00:00";
                                $isExpired = (strtotime($result->expirationTimestamp) > strtotime(time()) ? "Yes" : "No");
                                ?>
                                <tr>
                                    <td><?php esc_html_e($result->id); ?></td>
                                    <td><?php esc_html_e($result->offeror); ?></td>
                                    <td><?php esc_html_e($result->quantityWanted); ?></td>
                                    <td><?php esc_html_e(Marketplace::formatCurrency($result->pricePerToken));
                                        esc_html_e(" " . Helper::getCurrencyDataByPostId($postID)["symbol"]); ?></td>
                                    <td><?php esc_html_e($cannotExpire ? "Never" : $result->expirationTimestamp); ?></td>
                                    <td><?php esc_html_e($cannotExpire ? "No" : $isExpired); ?></td>
                                    <td>
                                        <a href="#" id="nft-marketplace-core-thirdweb-accept-offer"
                                           data-listing-id="<?php esc_attr_e($nft_marketplace_core_nft_marketplace_id); ?>"
                                           data-market-address="<?php esc_attr_e($additionalData["marketplace_address"]); ?>"
                                           data-offer-id="<?php esc_attr_e($result->listingId); ?>"
                                            <?php echo NFT_Marketplace_Core\Internals\Helpers\BlockchainDatasetBuilder::switchNetwork($additionalData["term_id"]) ?>
                                        >
                                            <button style="background: #22bc42"
                                                    class="single_nft_button button alt"><?php esc_html_e("Accept Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
                                        </a>
                                    </td>
                                </tr>
                            <?php } ?>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </main>
</div>
<?php
/**
 * Main Content: End of page
 */
get_footer(); ?>
