<?php
/*
* Template Name: NFT Listing Archive
*/

use NFT_Marketplace_Core\Internals\Metas\NFTMeta;

get_header();

/**
 * Theme Panel Setting for number of NFT listings on row
 * since version 1.0
 */
$class = '';
if (isset(get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_row'])) {
	$class = get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_row'];
} else {
	$class = 'col-md-4';
}


/**
 * Theme Panel Setting for sidebar display
 * since version 1.0
 */
if (isset(get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_select_sidebar'])) {
	$sidebar = get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_select_sidebar'];
}
$main_content = '';


/**
 * Plugin Breadcrumbs
 * since version 1.0
 */

do_action('nft_marketplace_core_before_main_content');


/**
 * Main Content : Start of the page
 * since version 1.0
 */


add_action('pre_get_posts', 'nft_marketplace_core_my_custom_post_type_query', 2429);
function nft_marketplace_core_my_custom_post_type_query($query)
{
	if (isset($_GET['search']) && $query->is_search()) {
		$query->set('post_type', 'nft-listing');
	}
}


function nft_marketplace_core_query()
{
	$nr_prod = '9';

	if (isset(get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_page'])) {
		$nr_prod = get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_page'];
	}

	$args = array(
		'posts_per_page' => $nr_prod,
		'post_type' => 'nft-listing',
		'post_status' => 'publish',
		'paged' => get_query_var('paged') ? get_query_var('paged') : 1,
		'meta_query' => array(
			'relation' => 'AND'
		),
		'tax_query' => array(
			'relation' => 'AND'
		)
	);

	if (isset($_GET['search']) && $_GET['search'] !== "") {
		$args['s'] = sanitize_text_field($_GET['search']);
	}
	if (isset($_GET['price_min']) && $_GET['price_min'] > 0 && isset($_GET['price_max']) && $_GET['price_min'] < $_GET['price_max']) {
		$args['meta_query'][] = array(
			'key' => NFTMeta::price,
			'value' => array(
				floatval(sanitize_text_field($_GET['price_min'])),
				floatval(sanitize_text_field($_GET['price_max']))
			),
			'type' => 'numeric',
			'compare' => 'BETWEEN'
		);
	}

	if (isset($_GET["status"])) {
		if ("Listed" === $_GET["status"]) {
			$args['meta_query'][] = array(
				'relation' => 'AND',
				array(
					'key' => NFTMeta::quantity,
					'compare' => 'EXISTS'
				),
				array(
					'key' => NFTMeta::quantity,
					'value' => 0,
					'compare' => '>'
				),
				array(
					'key' => NFTMeta::quantity,
					'value' => '',
					'compare' => '!='
				)
			);
		}

		if ("Not Listed" === $_GET["status"]) {
			$args['meta_query'][] = array(
				'key' => NFTMeta::quantity,
				'compare' => 'NOT EXISTS'
			);
		}

		if ("Starting Soon" === $_GET["status"]) {
			$args['meta_query'][] = array(
				'key' => NFTMeta::startTime,
				'value' => time(),
				'compare' => '>'
			);
		}
	}

	if (isset($_GET["orderby"])) {
		if ($_GET["orderby"] === "price_low") {
			$args['meta_key'] = NFTMeta::price;
			$args['orderby'] = 'meta_value_num';
			$args['order'] = 'ASC';
		} else if ($_GET["orderby"] === "price_high") {
			$args['meta_key'] = NFTMeta::price;
			$args['orderby'] = 'meta_value_num';
			$args['order'] = 'DESC';
		} else if ($_GET["orderby"] === "quantity") {
			$args['meta_key'] = NFTMeta::quantity;
			$args['orderby'] = 'meta_value_num';
			$args['order'] = 'ASC';
		} else if ($_GET["orderby"] === "views") {
			$args['meta_key'] = NFTMeta::views;
			$args['orderby'] = 'meta_value_num';
			$args['order'] = 'DESC';
		} else if ($_GET["orderby"] === "date") {
			$args['orderby'] = 'date';
		} else if ($_GET["orderby"] === "title") {
			$args['orderby'] = 'title';
			$args['order'] = 'ASC';
		}
	}

	foreach ($_GET as $key => $value) {
		if (strpos($key, 'taxonomy_') === 0) {
			$taxonomy = str_replace('taxonomy_', '', $key);
			$args['tax_query'][] = array(
				'taxonomy' => $taxonomy,
				'field' => 'slug',
				'terms' => is_array($value) ? array_map('sanitize_text_field', $value) : sanitize_text_field($value)
			);
		}
	}

	return new wp_query($args);
}

$my_query = nft_marketplace_core_query();
$index = 0;

$perRow = 12 / intval(str_replace("col-md-", "", $class));

$postCount = $my_query->post_count;


function archive_listings_count_template()
{
	$nr_prod = 9;

	if (isset(get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_page'])) {
		$nr_prod = get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_items_per_page'];
	}

	$nfts_query = nft_marketplace_core_query();
	$query_page = (get_query_var('paged')) ? get_query_var('paged') : 1;
	$total = $nfts_query->found_posts;

	if ($nr_prod > $total) {
		$nr_prod = $total;
	}

	echo '<div class="nft-marketplace-taxonomy-count col-md-9">';
	echo esc_html__('Showing ' . (get_query_var('paged') ? (($nr_prod * $query_page) > $total ? ($total - ($nr_prod * ($query_page - 1))) : $nr_prod) : $nr_prod) . ' out of ' .esc_attr($total) . ' results' , NFT_MARKETPLACE_CORE_TEXTDOMAIN);
	echo '</div>';
}

add_action('nft_marketplace_core_archive_before_grid_template', 'archive_listings_count_template', 10);

?>
<div class="high-padding">
	<div class="container blog-posts content-area">
		<div class="row">
			<?php if (isset(get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_sidebar']) && get_option('nft_marketplace_core_panel_shop_page')['nft_marketplace_core_sidebar'] == 'on') { ?>
				<?php $main_content = 'col-md-9';
				if (is_active_sidebar($sidebar)) { ?>
					<div id="sidebar" class="col-md-3 ">
						<?php dynamic_sidebar($sidebar); ?>
					</div>
				<?php } ?>
			<?php } else {
				$main_content = 'col-md-12';
			} ?>
			<div class="<?php echo esc_attr($main_content); ?>">

				<?php
				/**
				 * Hook: Before The NFT Listings (Set: Ordering, Count)
				 */
				do_action('nft_marketplace_core_archive_before_grid_template'); ?>

				<div class="main-content">
					<?php

					?>
					<?php if ($my_query->have_posts()) : ?>

					<?php
					echo "<div class='container-fluid'>";
					echo "<div class='row'>";

					while ($my_query->have_posts()) : $my_query->the_post();
						$index++;
						?>
						<article id="post-<?php the_ID(); ?>" class="nft-listing <?php echo esc_attr($class); ?> ">
							<?php
							/**
							 * Hook: NFT Listing query (Set: Single NFT Block)
							 */
							do_action('nft_marketplace_core_archive_listing_query_template'); ?>
						</article>
						<?php
						if ($index % $perRow === 0) {
							echo "</div>";
							if ($index !== ($postCount)) {
								echo "<div class='row'>";
							}
						}
					endwhile; ?>
				</div>
			</div>
		<?php wp_reset_query();
		remove_action('pre_get_posts', 'my_custom_post_type_query', 2429);
		$big = 999999999; // need an unlikely integer
		echo '<div class="modeltheme-pagination-holder col-md-12">';
		echo '<div class="modeltheme-pagination pagination">';
		echo paginate_links(array(
			'base' => str_replace($big, '%#%', get_pagenum_link($big)),
			'format' => '?paged=%#%',
			'current' => max(1, get_query_var('paged')),
			'total' => $my_query->max_num_pages,
//                    'show_all' => false,
//                    'type' => 'plain',
//                    'end_size' => 2,
//                    'mid_size' => 1,
//                    'prev_next' => false,
//                    'add_args' => false,
//                    'add_fragment' => '',
		));
		echo '</div>';
		echo '</div>';

		/**
		 * Hook: After The NFT Listings (Set: Pagination)
		 */
//		do_action('nft_marketplace_core_archive_after_grid_template'); ?>

		<?php else : ?>
			<?php echo apply_filters('nft_marketplace_core_no_listings_found', esc_html__('There are no NFT Listings', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?>
		<?php endif; ?>
		</div>
	</div>
</div>
</div>
</div>

<?php
/**
 * Main Content : End of the page
 * since version 1.0
 */
get_footer(); ?>
