<?php

use Brick\Math\BigDecimal;
use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;

global $post;

$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postId, 'nft_listing_blockchains');
$contractHelper = Helper::contractHelperFromPostId($postId, $additionalData);
$isOnSale = Marketplace::isNFTOnSale($postid);
$nft_url = get_permalink($post->ID);

$current_user = get_current_user_id();
$nft_marketplace_core_nft_listing_price = get_post_meta($postId, 'nft_marketplace_core_nft_listing_currency_price', true);

$price = esc_attr(Marketplace::formatCurrency($nft_marketplace_core_nft_listing_price));

$customTokenAddress = get_post_meta($postid, "nft_marketplace_core_nft_listing_currency", true);
if ($customTokenAddress !== "0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee" && $customTokenAddress !== "") {
	if ($customTokenAddress === "0x596a61a4daa09afd4169a4ed75a5035fe6e3917e") {
		$price = esc_attr(BigDecimal::of($nft_marketplace_core_nft_listing_price)->exactlyDividedBy(BigDecimal::of(10)->power(6)));
	} else if ($customTokenAddress === "0x93521c8c6ab1a0af419420cb71b8de216aa0472b") {
		$price = esc_attr(BigDecimal::of($nft_marketplace_core_nft_listing_price)->exactlyDividedBy(BigDecimal::of(10)->power(9)));
	}
	$currencyTermId = Helper::getCurrencyByContractAddress($customTokenAddress)[0]->term_id;
	$currencyTermMeta = get_term_meta($currencyTermId, "nft_marketplace_core_taxonomy_currency_symbol", true);
}

$date = get_the_date('F j, Y', $postId);
$author_id  = get_post_field( 'post_author', $postid );
$isExplicit = get_post_meta($postid, "nft_marketplace_core_nft_listing_explicit_meta", true);
$nft_marketplace_blockchain_symbol =  NFT_Marketplace_Core\Internals\Helpers\Assets::getCurrencyImageSrcByTermId($additionalData["term_id"], [20, 20]);

$nft_marketplace_core_nft_listing_description_meta = get_post_meta($postid, 'nft_marketplace_core_nft_listing_description_meta', true);

wp_enqueue_style('nft-marketplace-core-card-v2', plugin_dir_url(NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION).'/assets/css/versions/card-v2.css');
?>

<div class="nft-card-wrapper-v2 hover-shine">
	<div class='main'>
		<a class="nft-listing-media-v2" href="<?php echo esc_url(get_the_permalink($postid));?>">
			<?php echo Assets::getNFTDisplayAsset($postId, 'card', false);?>
		</a>
		<a href="<?php echo esc_url(get_the_permalink($postid));?> ">
			<h3 class="nft-title"><?php esc_html(get_the_title($postid));?></h3>
		</a>
		<p class='description'><?php echo esc_html($nft_marketplace_core_nft_listing_description_meta); ?></p>
		<div class='tokenInfo'>
			<div class="price">
				<p>
					<?php
						if ($isOnSale) {
							if ($customTokenAddress !== "0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee" && $customTokenAddress !== "") {
								echo Assets::getCurrencyImageSrcByTermId($currencyTermId, [20, 20]) . ' ' . esc_attr($price) . ' ' . esc_html($currencyTermMeta);
							} else {
								echo $nft_marketplace_blockchain_symbol; echo $nft_marketplace_core_nft_listing_price; echo  esc_attr($additionalData["currency_symbol"]);
							}
						} else {
							echo esc_html_e("NFT not listed.", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
						}
					?>
				</p>
			</div>
			<div class="duration">
				<p><i class="fas fa-clock"></i><?php esc_html_e("Created on", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> <?php echo $date; ?></p>
			</div>
		</div>
		<hr />
		<div class='creator'>
				<a href="<?php echo esc_url(get_the_permalink($postid));?>" class="nft-author-image">
					<img src="<?php echo get_avatar_url($author_id);?>">
				</a>
			<p>
                <?php esc_html_e("Creation of", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
                <span>
                    <?php echo apply_filters("nft_marketplace_core_process_display_name", $author_id); ?>
                </span>
            </p>
		</div>
	</div>
</div>



