<?php

use Brick\Math\BigDecimal;
use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;

global $post;

$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postid, 'nft_listing_blockchains');
$contractHelper = Helper::contractHelperFromPostId($postid, $additionalData);
$isOnSale = Marketplace::isNFTOnSale($postid);
$nft_url = get_permalink($post->ID);

$current_user = get_current_user_id();
$nft_marketplace_core_nft_listing_price = get_post_meta($postid, "nft_marketplace_core_nft_listing_currency_price", true);

$price = esc_attr(Marketplace::formatCurrency($nft_marketplace_core_nft_listing_price));

$customTokenAddress = get_post_meta($postid, "nft_marketplace_core_nft_listing_currency", true);
if ($customTokenAddress !== "0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee" && $customTokenAddress !== "") {
	if ($customTokenAddress === "0x596a61a4daa09afd4169a4ed75a5035fe6e3917e") {
		$price = esc_attr(BigDecimal::of($nft_marketplace_core_nft_listing_price)->exactlyDividedBy(BigDecimal::of(10)->power(6)));
	} else if ($customTokenAddress === "0x93521c8c6ab1a0af419420cb71b8de216aa0472b") {
		$price = esc_attr(BigDecimal::of($nft_marketplace_core_nft_listing_price)->exactlyDividedBy(BigDecimal::of(10)->power(9)));
	}
	$currencyTermId = Helper::getCurrencyByContractAddress($customTokenAddress)[0]->term_id;
	$currencyTermMeta = get_term_meta($currencyTermId, "nft_marketplace_core_taxonomy_currency_symbol", true);
}

$date = get_the_date('F j, Y', $postid);
$author_id  = get_post_field( 'post_author', $postid );
$isExplicit = get_post_meta($postid, "nft_marketplace_core_nft_listing_explicit_meta", true);

$collection = get_the_terms( get_the_ID(), 'nft-listing-collection');
$collection_image_url = '';
$collection_description = '';
if(isset($collection[0]) && $collection[0]) {
    $collection_id = $collection[0]->term_id;
    $collection_image_id = get_term_meta( $collection_id, 'collection-image-id', true);
    $collection_image_url = wp_get_attachment_image_url($collection_image_id,'thumbnail');
    $collection_image_url = $collection_image_url === false ? Assets::getPlaceholderLocation() : $collection_image_url;
    $collection_description = category_description($collection_id);
}

wp_enqueue_style('nft-marketplace-core-card-v6', plugin_dir_url(NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION).'/assets/css/versions/card-v6.css');
?>
<div class="nft-card-v6-wrapper">
	<div class='main'>
		<div class="nft-listing-wrapper-v6">
			<a class="nft-listing-media-v6" href="<?php echo esc_url(get_the_permalink($postid));?>">
				<?php echo Assets::getNFTDisplayAsset($postid, 'card', false);?>
			</a>
		</div>
		<div class="nft-card-v6-content">
			<div class="nft-card-v6-name"><?php echo get_the_title($postid);?></div>
			<div class="nft-card-v6-collection-name">
				<?php
				if($collection) { ?>
					<?php do_action('nft_marketplace_core_single_nft_after_title_collection'); ?>
				<?php	} else { ?>
					<?php echo esc_html__('No Collection', NFT_MARKETPLACE_CORE_TEXTDOMAIN);?>
				<?php	}
				?>
			</div>
			<div class="nft-card-v6-price-group">
				<div class="nft-card-v6-price-title"><?php echo esc_html__('Price:', NFT_MARKETPLACE_CORE_TEXTDOMAIN);?></div>
				<div class="nft-card-v6-price">
					<?php
					if ($isOnSale) {
						if ($customTokenAddress !== "0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee" && $customTokenAddress !== "") {
							echo '<span class="nft-listing-price">' . Assets::getCurrencyImageSrcByTermId($currencyTermId, [18, 18]) . ' ' . esc_attr($price) . ' ' . esc_html($currencyTermMeta) . '</span>';
						} else {
							echo '<span class="nft-listing-price">' . Assets::getNFTDisplayAsset($additionalData["term_id"], [18, 18]) . ' ' . esc_attr($price) . ' ' . esc_attr($additionalData["currency_symbol"]) . '</span>';
						}
					} else {
						echo '<span>' . esc_html_e("NFT not listed.", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . '</span>';
					}
					?>
				</div>
			</div>
			<div class="nft-buy-v6">
				<?php
				if ($isOnSale) { ?>
					<a href="<?php echo esc_url(get_the_permalink($postid));?>">
						<button type="button" class="nft-buy-btn-v6"><?php echo esc_html__("Buy Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></button>
					</a>
				<?php } elseif (!$isOnSale && $author_id==$current_user){ ?>
					<a href="<?php echo add_query_arg(["list-nft" => true], get_permalink()) ?>">
						<button type="button" class="nft-buy-btn-v6"><?php echo esc_html__("List NFT", NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></button>
					</a>
				<?php	} else { ?>
					<a href="<?php echo esc_url("$nft_url");?>">
						<button type="button" class="nft-buy-btn-v6"><?php echo esc_html__("View NFT", NFT_MARKETPLACE_CORE_TEXTDOMAIN)?></button>
					</a>
				<?php	}
				?>
			</div>
		</div>
	</div>
</div>




