<?php

use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\BlockchainDatasetBuilder;
use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Metas\NFTMeta;

$postID = get_the_ID();
$contractHelper = Helper::contractHelperFromPostId($postID, $additionalData);

global $wpdb;

/**
 * Define single NFT price,symbol,regular price
 */
$nft_marketplace_core_nft_listing_token_id = get_post_meta($postID, 'nft_marketplace_core_nft_listing_token_id', true);
$nft_marketplace_core_nft_listing_address = get_post_meta($postID, 'nft_marketplace_core_nft_listing_address', true);
$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postID, 'nft_listing_blockchains');
$nft_marketplace_core_nft_listing_price = get_post_meta($postID, 'nft_marketplace_core_nft_listing_currency_price', true);
$nft_marketplace_core_nft_listing_usd_price = null;

$author = get_post($postID)->post_author;


$nft_marketplace_core_nft_marketplace_id = get_post_meta($postID, 'nft_marketplace_core_nft_marketplace_id', true);
$nft_marketplace_core_nft_listing_start_time = get_post_meta($postID, 'nft_marketplace_core_nft_listing_start_time', true);
$listingStarted = time() > $nft_marketplace_core_nft_listing_start_time;
$hasItemLeftToSell = get_post_meta($postID, "nft_marketplace_core_nft_listing_quantity", true) > 0;
$listingNotExpired = get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true) > time();

$isItemOnSale = $listingStarted && $hasItemLeftToSell && $listingNotExpired;


get_header();


/**
 * Main Content: Breadcrumbs
 */
do_action('nft_marketplace_core_before_main_content');
?>
	<div id="primary" class="content-area">
		<main id="main" class="site-main" role="main">
			<div class="high-padding">
				<div class="container blog-posts single-nft">
					<div class="row">
						<div class="col-md-12 main-content row">
							<div class="col-md-6 nft-thumbnails">
								<div>
									<?php echo Assets::getNFTDisplayAsset(get_the_ID()); ?>
								</div>
							</div>
							<div class="summary nft-entry-summary col-md-6">
								<?php //Wishlist button // ?>
								<div class="nft-listing-infos-wrapper">
									<?php
									/**
									 * Hook: Before Title (Set: Author, Likes, Views)
									 */
									do_action('nft_marketplace_core_single_nft_before_title'); ?>
								</div>
								<h2 itemprop="name"
									class="nft_title entry-title"><?php echo esc_html(get_the_title()); ?></h2>
								<?php
								if (is_numeric($nft_marketplace_core_nft_marketplace_id)) {
									?>
									<p class="nft-marketplace-core-tooltip">
										<?php echo esc_html__("Published on", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?>
										<?php echo Assets::getCurrencyImageSrcByTermId($additionalData["term_id"], [20, 20]); ?>
										<?php echo $nft_marketplace_core_nft_listing_blockchains_term[0]->name; ?>
										<span class="nft-marketplace-core-tooltiptext">
											<?php echo $additionalData["marketplace_address"]; ?>
                                    	</span>
									</p>
									<?php
								}
								if (get_the_terms($postID, 'nft-listing-category')) {
									?>
									<div class="single-collection-title">

										<?php
										/**
										 * Hook: After Title (Set Category name)
										 */

										?>
										<?php do_action('nft_marketplace_core_single_nft_after_title_category'); ?>

										<span><?php echo apply_filters('nft_marketplace_core_category_title', esc_html__('Category', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?></span>

									</div>
								<?php }

								if (get_the_terms($postID, 'nft-listing-collection')) {
									?>
									<div class="single-collection-title">

										<?php
										/**
										 * Hook: After Title (Set Collection name)
										 */

										?>
										<?php do_action('nft_marketplace_core_single_nft_after_title_collection'); ?>

										<span><?php echo apply_filters('nft_marketplace_core_collection_title', esc_html__('Collection', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?></span>

									</div>

								<?php } ?>

								<div class="product_meta">
									<?php if ($isItemOnSale) { ?>
										<span><?php esc_html_e("Quantity", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>: <span><?php esc_html_e(get_post_meta($postID, "nft_marketplace_core_nft_listing_quantity", true)) ?></span></span>
										<span><?php esc_html_e("Listing Type", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>: <span><?php esc_html_e(ucfirst(get_post_meta($postID, "nft_marketplace_core_nft_listing_type", true))) ?></span></span>
									<?php } ?>
									<span><?php esc_html_e("NFT's Contract Address", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>: <span><?php esc_html_e($nft_marketplace_core_nft_listing_address) ?></span></span>
									<span><?php esc_html_e("Token ID", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>: <span><?php esc_html_e($nft_marketplace_core_nft_listing_token_id) ?></span></span>

									<?php if ($isItemOnSale) { ?>
										<span>
											<?php esc_html_e("Ending", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>:
											<span><?php esc_html_e(wp_date('l, F jS, Y \a\t g:i A', get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true))) ?></span>
										</span>
									<?php } ?>
								</div>

								<?php
								if ($isItemOnSale) { ?>

									<div class="nft-listing-crypto-price">
										<?php Helper::getCurrencyDisplayDataByPostId($postID); ?>
									</div>
								<?php }
								if (!empty($nft_marketplace_core_nft_listing_blockchains_term)) {
									do_action('nft_marketplace_core_before_button', $isItemOnSale);

									if (!$listingStarted) {
										?>
										<br/>
										<h4><?php esc_html_e("Listing will start ", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . esc_html_e(wp_date('l, F jS, Y', $nft_marketplace_core_nft_listing_start_time)); ?></h4>
										<button style="display: inline-block;margin-right: 15px;"
												type="submit" name="nft_marketplace_core_buy_data"
												class="single_nft_button button alt" disabled>
											<?php echo apply_filters('nft_marketplace_core_purchase_btn', esc_html__('Purchase Now', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?>
										</button>
										<?php
									} elseif ($isItemOnSale) {
										?>
										<form method="post"
											  style="display: inline-block;margin-right: 15px;"
											<?php echo BlockchainDatasetBuilder::purchaseListing($nft_marketplace_core_nft_marketplace_id, $additionalData["marketplace_address"], $additionalData["term_id"]); ?>
										>
											<button type="submit" name="nft_marketplace_core_buy_data"
													class="single_nft_button button alt">
												<?php echo apply_filters('nft_marketplace_core_purchase_btn', esc_html__('Purchase Now', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?>
											</button>
										</form>
									<?php } elseif (get_current_user_id() === (int)$author) { ?>
										<a href="<?php echo add_query_arg(["list-nft" => true], get_permalink()) ?>">
											<button
												class="single_nft_button button alt"><?php esc_html_e("Sell Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
										</a>
										<?php
									}

									do_action('nft_marketplace_core_after_button', $isItemOnSale); ?>
									<?php if ($isItemOnSale || !$listingStarted) { ?>
										<a href="#"
											<?php echo BlockchainDatasetBuilder::cancelListing($nft_marketplace_core_nft_marketplace_id, $additionalData["marketplace_address"], $additionalData["term_id"]); ?>
										   class="single_nft_button button alt"><?php esc_html_e("Cancel Listing", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
									<?php } ?>

									<br/>

									<?php if ($isItemOnSale) {
										?>
										<a href="#"
										   id="nft-marketplace-core-make-offer"
											<?php
											echo BlockchainDatasetBuilder::makeOffer(
												$additionalData["chain_id"],
												$nft_marketplace_core_nft_listing_token_id,
												$nft_marketplace_core_nft_listing_address,
												1,
												get_post_meta($postID, "nft_marketplace_core_nft_listing_currency", true),
												$additionalData["marketplace_address"],
												$additionalData["term_id"]);
											?>
										>
											<button
												class="single_nft_button button alt"><?php esc_html_e("Make Offer", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
										</a>
									<?php } ?>
									<?php
									// Add edit button for the author
									if (get_current_user_id() === (int)$author) {
										?>
										<?php if (get_post_meta($postID, "nft_marketplace_core_nft_listing_content_meta", true)) { ?>
											<a href="<?php echo add_query_arg(["unlock-nft-content" => true], get_permalink()) ?>">
												<button
													class="single_nft_button button alt"><?php esc_html_e("Unlock", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
											</a>
										<?php } ?>
										<a href="<?php echo add_query_arg(["edit-nft" => true], get_permalink()) ?>"
										   class="single_nft_button button alt"><?php esc_html_e("Edit", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>

										<a href="<?php echo add_query_arg(["offer-list" => $postID], get_permalink()) ?>"
										   class="single_nft_button button alt"><?php esc_html_e("Offers", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
									<?php } ?>


									<?php
									/**
									 * Hook: After Metas (Set Tabs Aside)
									 */
									?>
								<?php }
								if (!isset(get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs']) || get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs'] == 'top') { ?>
									<?php do_action('nft_marketplace_core_single_nft_after_metas'); ?>
								<?php } ?>
							</div>
						</div>
					</div>

					<?php
					/**
					 * Hook: After Metas (Set Tabs Below)
					 */
					?>
					<?php if (isset(get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs']) && get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs'] == 'bellow') { ?>
						<?php do_action('nft_marketplace_core_single_nft_before_related'); ?>
					<?php } ?>

					<?php
					/**
					 * Hook: Related NFT after content
					 */
					?>
					<?php do_action('nft_marketplace_core_single_nft_related'); ?>

				</div>
			</div>
		</main>
	</div>

<?php get_footer(); ?>
