<?php
get_header();

use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\BlockchainDatasetBuilder;
use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;
use NFT_Marketplace_Core\Internals\Metas\NFTMeta;

$postID = get_the_ID();
$contractHelper = Helper::contractHelperFromPostId($postID, $additionalData);
$post = get_post($postID);

$nft_marketplace_core_nft_listing_token_id = get_post_meta($postID, 'nft_marketplace_core_nft_listing_token_id', true);
$nft_marketplace_core_nft_listing_address = get_post_meta($postID, 'nft_marketplace_core_nft_listing_address', true);
$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postID, 'nft_listing_blockchains');
$nft_marketplace_core_nft_listing_price = get_post_meta($postID, 'nft_marketplace_core_nft_listing_currency_price', true);
$nft_marketplace_blockchain_symbol = Assets::getCurrencyImageSrcByTermId($additionalData["term_id"], [20, 20]);

do_action('nft_marketplace_core_before_main_content');
$nft_marketplace_core_nft_marketplace_id = get_post_meta($postID, 'nft_marketplace_core_nft_marketplace_id', true);
$nft_marketplace_core_nft_listing_start_time = get_post_meta($postID, 'nft_marketplace_core_nft_listing_start_time', true);
$listingStarted = time() > $nft_marketplace_core_nft_listing_start_time;

$nft_marketplace_core_nft_listing_description_meta = get_post_meta(get_the_ID(), 'nft_marketplace_core_nft_listing_description_meta', true);

$auth_id = $post->post_author;

$isItemOnSale = Marketplace::isNFTOnSale($postID);

$author = $post->post_author;

$author = get_post($postID)->post_author;
$theAuthorId = get_the_author_meta('ID');
$getUserUrl = get_avatar_url($theAuthorId);
$author_link = get_author_posts_url($author);
$author_avatar = get_avatar_url($author);
$author_id = get_post_field('post_author', get_the_ID());

$collection = get_the_terms(get_the_ID(), 'nft-listing-collection');
$collection_image_url = '';
$collection_description = '';
if (isset($collection[0]) && $collection[0]) {
	$collection_id = $collection[0]->term_id;
	$collection_image_id = get_term_meta($collection_id, 'collection-image-id', true);
	$collection_image_url = wp_get_attachment_image_url($collection_image_id, 'thumbnail');
	$collection_image_url = $collection_image_url === false ? Assets::getPlaceholderLocation() : $collection_image_url;
	$collection_description = category_description($collection_id);
}

wp_enqueue_style('nft-marketplace-core-single-nft-v1', plugin_dir_url(NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION) . '/assets/css/versions/single-nft-v1.css');
function nft_marketplace_core_relative_time()
{
	return sprintf(esc_html__('%s ago', NFT_MARKETPLACE_CORE_TEXTDOMAIN), human_time_diff(get_the_time('U'), current_time('timestamp')));
}

?>
<div id="primary" class="content-area">
	<main id="main" class="site-main" role="main">
		<div class="blog-posts single-nft">
			<div class="row">
				<div class="col-md-12 nft-thumbnails text-center">
					<?php echo Assets::getNFTDisplayAsset(get_the_ID()); ?>
				</div>
			</div>
			<div class="single-nft-content container">
				<div class="row nft-info-section section-spacer">
					<div class="col-lg-5 col-md-5 col-sm-12 col-12">
						<div class="nft-basic-info">
							<div class="nft-views d-flex">
								<?php do_action('nft_marketplace_core_single_nft_before_title'); ?>
								<?php do_action('nft_marketplace_core_single_nft_under_title'); ?>
							</div>
							<h2 class="nft-content-title"><?php echo esc_html(the_title()); ?></h2>
							<span
								class="nft-minted"><?php esc_html_e("Minted on", NFT_MARKETPLACE_CORE_TEXTDOMAIN);
								echo " " . get_the_date('F j, Y', get_the_ID()); ?>
                                <svg width="16px" height="16px" fill="none" xmlns="http://www.w3.org/2000/svg"
									 viewBox="0 0 16 16">
                                    <path
										d="M5.1 4.707h4.75l-6.885 6.885a1.02 1.02 0 1 0 1.443 1.443l6.885-6.886v4.75a1.02 1.02 0 0 0 2.04 0V3.688a1.02 1.02 0 0 0-1.02-1.02H5.1a1.02 1.02 0 0 0 0 2.04Z"
										fill="currentColor"></path>
                                </svg>
                            </span>
						</div>
						<div class="nft-content-creators d-flex flex-wrap">
							<div class="nft-creator-col">
								<span
									class="nft-creator-text"><?php esc_html_e("Created by", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
								<div class="author-badge-wrapper">
									<div class="author-badge">
										<a href="<?php echo esc_url(get_author_posts_url($author_id)); ?>"
										   class="nft-author-image">
											<img src="<?php echo esc_url($author_avatar); ?>"
												 alt="<?php esc_attr_e(the_title()) ?>">
											<span>
                                                <?php echo apply_filters("nft_marketplace_core_process_display_name", $author_id); ?>
                                            </span>
										</a>
									</div>
									<div class="author-badge-extended">
										<div class="author-badge-extended-img-group d-flex justify-content-between">
											<img src="<?php echo $author_avatar; ?>"
												 alt="<?php esc_attr_e(the_title()) ?>">
											<a href="<?php echo esc_url(get_author_posts_url($author_id)); ?>">
												<button type="button"
														class="nft-follow-btn"><?php esc_html_e("Follow", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>
											</a>
										</div>
										<div class="author-badge-extended-info">
											<h3>
												<?php echo apply_filters("nft_marketplace_core_process_display_name", $author_id); ?>
											</h3>
										</div>
									</div>
								</div>
							</div>
							<?php
							if (get_the_terms($postID, 'nft-listing-collection')) {
								?>
								<div class="nft-collection-col">
									<span
										class="nft-creator-text"><?php esc_html_e("Collection", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
									<div class="collection-badge-wrapper">
										<div class="collection-badge">
											<a href="<?php echo esc_url(get_the_permalink()); ?>"
											   class="nft-collection-image">
												<img src="<?php echo esc_url($collection_image_url); ?>"
													 alt="<?php the_title(); ?>"/>
												<?php do_action('nft_marketplace_core_single_nft_after_title_collection'); ?>
											</a>
										</div>
										<div class="collection-badge-extended">
											<div
												class="collection-badge-extended-img-group d-flex justify-content-between">
												<img src="<?php echo esc_url($collection_image_url); ?>"
													 alt="<?php the_title(); ?>"/>
												<a href="<?php echo esc_url(get_the_permalink()); ?>">
													<button type="button"
															class="nft-follow-btn"><?php esc_html_e("Follow", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>
												</a>
											</div>
											<h3 class="collection-name"><?php do_action('nft_marketplace_core_single_nft_after_title_collection'); ?></h3>
										</div>
									</div>
								</div>
								<?php
							}
							?>
						</div>
					</div>
					<div class="col-lg-5 col-md-5 col-sm-12 col-12">
						<div class="nft-bid-section">
							<div class="nft-bid-price">
								<?php
								if (get_post_meta($postID, NFTMeta::listingType, true) === "auction") {
									?>
									<h4><?php esc_html_e("Auction will end in:", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></h4>

									<?php
								}
								if (get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true) < 1893456000 && time() < get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true)) {
									?>
									<div id="countdown"
										 data-countdown="<?php esc_attr_e(date('m/d/Y H:i:s', get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true))) ?>">
										<div class="counter" count="days"><span
												b="--"></span><b><?php esc_html_e("Days", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
										<div class="counter" count="hours"><span
												b="--"></span><b><?php esc_html_e("Hrs", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
										<div class="counter" count="minutes"><span
												b="--"></span><b><?php esc_html_e("Min", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
										<div class="counter" count="seconds"><span
												b="--"></span><b><?php esc_html_e("Sec", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
									</div>
									<?php
								} elseif (time() < get_post_meta($postID, NFTMeta::startTime, true)) {
									?>
									<div id="countdown"

										 data-countdown="<?php esc_attr_e(date('m/d/Y H:i:s', get_post_meta($postID, NFTMeta::startTime, true))) ?>">
										<div class="counter" count="days"><span
												b="--"></span><b><?php esc_html_e("Days", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
										<div class="counter" count="hours"><span
												b="--"></span><b><?php esc_html_e("Hrs", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
										<div class="counter" count="minutes"><span
												b="--"></span><b><?php esc_html_e("Min", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
										<div class="counter" count="seconds"><span
												b="--"></span><b><?php esc_html_e("Sec", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></b>
										</div>
									</div>
									<?php
								}
								?>
									<?php
									if ($isItemOnSale && get_post_meta($postID, NFTMeta::listingType, true) === "auction") { ?>
									<div>
										<div class="nft-listing-crypto-price d-flex justify-content-around"
											 id="nft-marketplace-core-auctions-to-update"
											 style="margin-top: 0"
											 data-marketplace-address="<?php esc_attr_e($additionalData["marketplace_address"]); ?>"
											 data-listing-id="<?php esc_attr_e($nft_marketplace_core_nft_marketplace_id); ?>"
										>
											<div class='mb-3 me-5' style="    font-size: 20px;"
												 id="nft-marketplace-core-auctions-current-bid">
												<?php
												esc_html_e('Current:', NFT_MARKETPLACE_CORE_TEXTDOMAIN);
												echo "<br/>";
												Helper::getCurrencyDisplayDataByPostId($postID); ?>
											</div>
											<div class='mb-3 me-5 ' style="    font-size: 20px;"
												 id="nft-marketplace-core-auctions-next-bid">
												<?php
												esc_html_e('Minimum:', NFT_MARKETPLACE_CORE_TEXTDOMAIN);
												echo "<br/>";
												$termData = get_the_terms($postID, "nft_listing_blockchains")[0];

												$customTokenAddress = get_post_meta($postID, "currency", true);
												$increasePercentage = 5; // Bid buffer
												$increaseAmount = $nft_marketplace_core_nft_listing_price * ($increasePercentage / 100);
												$newValue = $nft_marketplace_core_nft_listing_price + $increaseAmount;

												if ($newValue == 0) {
													$newValue = "10000000000000000";
												}

												Helper::getCurrency($newValue, $termData->term_id, $customTokenAddress);
												?>
											</div>
											<div class='mb-3' style="    font-size: 20px;">
												<?php
												esc_html_e('Buyout:', NFT_MARKETPLACE_CORE_TEXTDOMAIN);
												echo "<br/>";

												Helper::getCurrency(get_post_meta($postID, NFTMeta::buyoutPrice, true), $termData->term_id, $customTokenAddress);
												?>
											</div>
										</div>
										<?php }
										if (get_post_meta($postID, NFTMeta::listingType, true) === "auction" && is_user_logged_in()) { ?>
										<div>

											<form
												data-marketplace-address="<?php esc_attr_e($additionalData["marketplace_address"]); ?>"
												data-listing-id="<?php esc_attr_e($nft_marketplace_core_nft_marketplace_id); ?>"
												data-form-id="nft-marketplace-core-bid-now"
												<?php echo BlockchainDatasetBuilder::switchNetwork($additionalData["term_id"]) ?>
												class="input-wrapper d-block mb-4" style="position: relative;"
												method="post" id="nft-marketplace-core-bid-now">
												<div class="d-flex align-items-center">
													<input type="number"
														   value="<?php esc_attr_e(Marketplace::formatCurrency($newValue)); ?>"
														   min="<?php esc_attr_e(Marketplace::formatCurrency($newValue)); ?>"
														   step="0.0001"
														   name="myBid"
														   id="myBid" class="me-4" required/>
													<button class="nft-bid-btn">
														<?php esc_html_e('Place Bid', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
													</button>
												</div>
											</form>


											<button id="nft-marketplace-core-auctions-purchase-now"
												<?php echo BlockchainDatasetBuilder::switchNetwork($additionalData["term_id"]) ?>
													data-marketplace-address="<?php esc_attr_e($additionalData["marketplace_address"]); ?>"
													data-listing-id="<?php esc_attr_e($nft_marketplace_core_nft_marketplace_id); ?>"
													data-buyout="<?php esc_attr_e(Marketplace::formatCurrency(get_post_meta($postID, NFTMeta::buyoutPrice, true))); ?>"
													class="nft-offer-btn mt-4" style="width: 100%">
												<?php esc_html_e('Purchase Now', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
											</button>
										</div>
									</div>
								<?php } ?>

									<?php
									if (get_post_meta($postID, NFTMeta::listingType, true) === "direct") {
										if ($isItemOnSale) {
											?>
											<h4><?php esc_html_e("Reserve:", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h4>

											<h2 class="nft-product-price">
												<?php Helper::getCurrencyDisplayDataByPostId($postID); ?>
											</h2>
										<?php } else { ?>
											<h4 class="nft-product-price">
												<?php esc_html_e("Not listed yet", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?>
											</h4>
										<?php } ?>

										<?php
										do_action('nft_marketplace_core_before_button', $isItemOnSale);

										if (!$listingStarted) {
											?>
											<br/>
											<h4><?php esc_html_e("Listing will start ", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . esc_html_e(wp_date('l, F jS, Y', $nft_marketplace_core_nft_listing_start_time)); ?></h4>
											<?php
										} elseif ($isItemOnSale) {

											?>
											<form method="post"
												<?php echo BlockchainDatasetBuilder::purchaseListing($nft_marketplace_core_nft_marketplace_id, $additionalData["marketplace_address"], $additionalData["term_id"]); ?>
											>
												<button type="submit" name="nft_marketplace_core_buy_data"
														class="nft-bid-btn">
													<?php echo apply_filters('nft_marketplace_core_purchase_btn', esc_html__('Purchase Now', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?>
												</button>
											</form>
											<?php
										}
									}

									if (!$isItemOnSale && get_current_user_id() === (int)$author) { ?>
										<a href="<?php echo add_query_arg(["list-nft" => true], get_permalink()) ?>">
											<button id="bid-btn"
													class="nft-bid-btn"><?php esc_html_e("Sell Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
										</a>
										<?php
									}
									?>
								</div>

							</div>
							<div class="nft-make-offer d-flex justify-content-between align-items-center">
								<h4><?php esc_html_e("Minted ", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><?php echo nft_marketplace_core_relative_time() ?></h4>
								<?php if ($isItemOnSale && get_post_meta($postID, NFTMeta::listingType, true) === "direct") { ?>
									<a href="#"
										<?php echo BlockchainDatasetBuilder::makeOffer($additionalData["chain_id"], $nft_marketplace_core_nft_listing_token_id, $nft_marketplace_core_nft_listing_address, 1, get_post_meta($postID, "nft_marketplace_core_nft_listing_currency", true), $additionalData["marketplace_address"], $additionalData["term_id"]); ?>
									>
										<button
											class="nft-offer-btn"><?php esc_html_e("Make Offer", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></button>
									</a>
								<?php } ?>
							</div>
							<div class="nft-owner d-flex text-center justify-content-center align-items-center">
								<span
									class="nft-owned-by"><?php esc_html_e("Owned by", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
								<div class="author-badge-wrapper">
									<div class="author-badge m-0">
										<a href="<?php echo esc_url($link); ?>" class="nft-author-image">
											<img src="<?php echo $author_avatar; ?>" alt="<?php echo the_title(); ?>">
											<span>
                                            <?php echo apply_filters("nft_marketplace_core_process_display_name", $author_id); ?>
                                        </span>
										</a>
									</div>
									<div class="author-badge-extended">
										<div class="author-badge-extended-img-group d-flex justify-content-between">
											<img src="<?php echo esc_url($author_avatar); ?>"
												 alt="<?php echo the_title(); ?>">
											<a href="<?php echo esc_url(get_author_posts_url($author_id)); ?>">
												<button type="button"
														class="nft-follow-btn"><?php echo esc_html__("Follow", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>
											</a>
										</div>
										<div class="author-badge-extended-info">
											<h3>
												<?php echo apply_filters("nft_marketplace_core_process_display_name", $author_id); ?>
											</h3>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
					<div class="row nft-info-section section-spacer">
						<div class="col-lg-5 col-md-5 col-sm-12 col-12">
							<div class="nft-description">
								<h3><?php esc_html_e("Description", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h3>
								<p class="nft-description-text"><?php echo esc_html($nft_marketplace_core_nft_listing_description_meta); ?></p>
							</div>
							<div class="nft-description nft-tags-title section-spacer">
								<?php
								$nft_marketplace_core_nft_listing_properties_group = get_post_meta(get_the_ID(), 'nft_marketplace_core_nft_listing_properties_group', true);
								$nft_marketplace_core_nft_listing_level_group = get_post_meta(get_the_ID(), 'nft_marketplace_core_nft_listing_level_group', true);
								$nft_marketplace_core_nft_listing_group = get_post_meta(get_the_ID(), 'nft_marketplace_core_nft_listing_group', true);

								if ($nft_marketplace_core_nft_listing_properties_group !== "" ||
									$nft_marketplace_core_nft_listing_level_group !== "" ||
									$nft_marketplace_core_nft_listing_group !== "") { ?>
									<h3><?php esc_html_e("Tags", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h3>
									<div class="nft-tags-list">
										<ul>
											<?php
											if ($nft_marketplace_core_nft_listing_properties_group) {
												foreach (array_reverse($nft_marketplace_core_nft_listing_properties_group) as $nft_listing) {
													echo '<li>';
													if (!empty($nft_listing['nft_marketplace_core_nft_listing_property_name'])) {
														echo esc_html($nft_listing['nft_marketplace_core_nft_listing_property_name']);
													}
													if (!empty($nft_listing['nft_marketplace_core_nft_listing_property_value'])) {
														echo ': ' . esc_html($nft_listing['nft_marketplace_core_nft_listing_property_value']);
													}
													echo '</li>';
												}
											}

											if ($nft_marketplace_core_nft_listing_level_group) {
												foreach (array_reverse($nft_marketplace_core_nft_listing_level_group) as $nft_listing) {
													echo '<li>';
													if (!empty($nft_listing['nft_marketplace_core_nft_listing_level_name'])) {
														echo esc_html($nft_listing['nft_marketplace_core_nft_listing_level_name']);
													}
													if ($nft_listing['nft_marketplace_core_nft_listing_level_rate'] == 0 || !empty($nft_listing['nft_marketplace_core_nft_listing_level_rate'])) {
														echo ': ' . esc_html($nft_listing['nft_marketplace_core_nft_listing_level_rate']);
													}
													echo '</li>';
												}
											}

											if ($nft_marketplace_core_nft_listing_group) {
												foreach (array_reverse($nft_marketplace_core_nft_listing_group) as $nft_listing) {
													echo '<li>';
													if (!empty($nft_listing['nft_marketplace_core_nft_listing_stat_name'])) {
														echo esc_html($nft_listing['nft_marketplace_core_nft_listing_stat_name']);
													}
													if (!empty($nft_listing['nft_marketplace_core_nft_listing_stat_rate'])) {
														echo ': ' . esc_html($nft_listing['nft_marketplace_core_nft_listing_stat_rate']);
													}
													echo '</li>';
												}
											}
											?>

										</ul>
									</div>
								<?php } ?>
								<div class="section-spacer">
									<div class="nft-share-btn-group d-flex flex-wrap">
										<?php if (($isItemOnSale || !$listingStarted)  && get_current_user_id() === (int) $author) { ?>
											<a href="#"
												<?php echo BlockchainDatasetBuilder::cancelListing($nft_marketplace_core_nft_marketplace_id, $additionalData["marketplace_address"], $additionalData["term_id"]); ?>
											   class="nft-btn-share follow-btn"><?php esc_html_e("Cancel Listing", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
										<?php } elseif (($isItemOnSale || !$listingStarted) && get_current_user_id() === (int) $author && !get_post_meta($postID, NFTMeta::cannotBeCanceled, true)) { ?>
											<a href="#"
												<?php echo BlockchainDatasetBuilder::cancelListing($nft_marketplace_core_nft_marketplace_id, $additionalData["marketplace_address"], $additionalData["term_id"], "nft-marketplace-core-cancel-auction"); ?>
											   class="nft-btn-share follow-btn"><?php esc_html_e("Cancel Auction", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
										<?php } ?>
										<?php
										// Add edit button for the author
										if (get_current_user_id() === (int)$author) {
											?>
											<?php if (get_post_meta($postID, "nft_marketplace_core_nft_listing_content_meta", true)) { ?>
												<a href="<?php echo add_query_arg(["unlock-nft-content" => true], get_permalink()) ?>">
													<button type="button" class="nft-btn-share follow-btn">
														<i class="fas fa-lock-open"></i>
														<span><?php esc_html_e("Unlock Content", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
													</button>
												</a>
											<?php } ?>
											<a href="<?php echo add_query_arg(["edit-nft" => true], get_permalink()) ?>">
												<button type="button" class="nft-btn-share follow-btn">
													<i class="fas fa-pen"></i>
													<span><?php esc_html_e("Edit", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
												</button>
											</a>
											<a href="<?php echo add_query_arg(["offer-list" => $postID], get_permalink()) ?>">
												<button type="button" class="nft-btn-share follow-btn">
													<i class="fas fa-list"></i>
													<span><?php esc_html_e("Offers", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
												</button>
											</a>
										<?php } ?>
									</div>
								</div>
							</div>
						</div>

						<div class="col-lg-5 col-md-5 col-sm-12 col-12">
							<div class="nft-description">
								<h3 class="nft-provenance-title"><?php esc_html_e("Provenance", NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h3>
								<ul class="nft-provenance-list">
									<li class="nft-provenance-list-item d-flex justify-content-between align-items-center">
										<div class="nft-provenance-info d-flex">
											<div class="nft-provenance-author-icon">
												<a href="<?php echo esc_url(get_author_posts_url($author_id)); ?>">
													<img src="<?php echo $author_avatar; ?>"
														 alt="<?php echo the_title(); ?>">
												</a>
											</div>
											<div class="nft-provenance-author-info">
												<span
													class="nft-provenance-author-action"><?php esc_html_e("Minted by", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></span>
												<span>
                                                <?php echo apply_filters("nft_marketplace_core_process_display_name", $author_id); ?>
                                            </span>
												<p><?php echo get_the_date('F j, Y', get_the_ID()) ?></p>
											</div>
										</div>
									</li>
								</ul>
							</div>
						</div>
					</div>

					<div class="row">
						<div class="col-12">
							<div class="nft-related-section">
								<?php
								/**
								 * Hook: After Metas (Set Tabs Below)
								 */
								?>
								<?php if (isset(get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs']) && get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs'] == 'bellow') { ?>
									<?php do_action('nft_marketplace_core_single_nft_before_related'); ?>
								<?php } ?>

								<?php
								/**
								 * Hook: Related NFT after content
								 */
								?>
								<?php do_action('nft_marketplace_core_single_nft_related'); ?>
							</div>
						</div>
					</div>
				</div>
	</main>
</div>
<?php
get_footer();
?>

