<?php
get_header();

use Brick\Math\BigDecimal;
use NFT_Marketplace_Core\Internals\Helpers\Assets;
use NFT_Marketplace_Core\Internals\Helpers\BlockchainDatasetBuilder;
use NFT_Marketplace_Core\Internals\Helpers\Helper;
use NFT_Marketplace_Core\Internals\Helpers\Marketplace;

global $post_id;

$postID = get_the_ID();
$contractHelper = Helper::contractHelperFromPostId($postID, $additionalData);

$nft_marketplace_core_nft_listing_token_id = get_post_meta($postID, 'nft_marketplace_core_nft_listing_token_id', true);
$nft_marketplace_core_nft_listing_address = get_post_meta($postID, 'nft_marketplace_core_nft_listing_address', true);
$nft_marketplace_core_nft_listing_blockchains_term = get_the_terms($postID, 'nft_listing_blockchains');
$nft_marketplace_core_nft_listing_price = get_post_meta($postID, 'nft_marketplace_core_nft_listing_currency_price', true);
$price = esc_attr(Marketplace::formatCurrency($nft_marketplace_core_nft_listing_price));

$customTokenAddress = get_post_meta($postID, "nft_marketplace_core_nft_listing_currency", true);
if ($customTokenAddress !== "0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee" && $customTokenAddress !== "") {
	if ($customTokenAddress === "0x596a61a4daa09afd4169a4ed75a5035fe6e3917e") {
		$price = esc_attr(BigDecimal::of($nft_marketplace_core_nft_listing_price)->exactlyDividedBy(BigDecimal::of(10)->power(6)));
	} else if ($customTokenAddress === "0x93521c8c6ab1a0af419420cb71b8de216aa0472b") {
		$price = esc_attr(BigDecimal::of($nft_marketplace_core_nft_listing_price)->exactlyDividedBy(BigDecimal::of(10)->power(9)));
	}
	$currencyTermId = Helper::getCurrencyByContractAddress($customTokenAddress)[0]->term_id;
	$currencyTermMeta = get_term_meta($currencyTermId, "nft_marketplace_core_taxonomy_currency_symbol", true);
}

$nft_marketplace_core_nft_listing_usd_price = null;
$nft_marketplace_blockchain_symbol =  NFT_Marketplace_Core\Internals\Helpers\Assets::getCurrencyImageSrcByTermId($additionalData["term_id"], [20, 20]);

do_action('nft_marketplace_core_before_main_content');
$nft_marketplace_core_nft_marketplace_id = get_post_meta($postID, 'nft_marketplace_core_nft_marketplace_id', true);
$nft_marketplace_core_nft_listing_start_time = get_post_meta($postID, 'nft_marketplace_core_nft_listing_start_time', true);
$listingStarted = time() > $nft_marketplace_core_nft_listing_start_time;
$hasItemLeftToSell = get_post_meta($postID, "nft_marketplace_core_nft_listing_quantity", true) > 0;
$listingNotExpired = get_post_meta($postID, 'nft_marketplace_core_nft_listing_end_time', true) > time();

$nft_marketplace_core_nft_listing_description_meta = get_post_meta(get_the_ID(), 'nft_marketplace_core_nft_listing_description_meta', true);

$auth_id = $post->post_author;

$isItemOnSale = $listingStarted && $hasItemLeftToSell && $listingNotExpired;
$blockchain_name = $nft_marketplace_core_nft_listing_blockchains_term[0]->name;
$nft_img_url = get_the_post_thumbnail_url(get_the_ID(),'full');

$author = get_post($postID)->post_author;
$author_link = get_author_posts_url($author);
$author_avatar = get_avatar_url($author);

$collection = get_the_terms( get_the_ID(), 'nft-listing-collection');
$collection_image_url = '';
$collection_description = '';
if(isset($collection[0]) && $collection[0]) {
    $collection_id = $collection[0]->term_id;
    $collection_image_id = get_term_meta( $collection_id, 'collection-image-id', true);
    $collection_image_url = wp_get_attachment_image_url($collection_image_id,'thumbnail');
    $collection_image_url = $collection_image_url === false ? Assets::getPlaceholderLocation() : $collection_image_url;
    $collection_description = category_description($collection_id);
}

$query = new WP_Query(array(
	"post_type" => "nft-listing",
	"posts_per_page" => -1,
	"author" => $auth_id,
	"fields" => "ids"
));
$posts = $query->posts;
$posts_count = count($posts);
$views_count = 0;
foreach ($posts as $temp_post_id) {
	$temp_views_count = (int)get_post_meta($temp_post_id, "nft_marketplace_core_post_views_count", true);
	$views_count = $views_count + $temp_views_count;
}

wp_enqueue_style('nft-marketplace-core-single-nft-v2', plugin_dir_url(NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION).'/assets/css/versions/single-nft-v2.css');
wp_enqueue_script('nft-marketplace-core-single-nft-v2', plugin_dir_url(NFT_MARKETPLACE_CORE_PLUGIN_MAIN_FILE_LOCATION).'/assets/js/versions/single-nft-v2.js');
?>
<div id="primary" class="content-area">
	<main id="main" class="site-main" role="main">
		<div class="blog-posts single-nft container">
			<div class="nft-single-v2-asset-row row">
				<div class="col-lg-2 col-md-2 col-sm-12 col-12 d-lg-block d-md-block d-sm-none d-none">
					<div class="nft-single-v2-img">
						<a href="<?php echo esc_url($nft_img_url);?>" alt="<?php echo the_title();?>" target="_blank">
							<?php echo NFT_Marketplace_Core\Internals\Helpers\Assets::getNFTDisplayAsset(get_the_ID()); ?>
						</a>
					</div>
				</div>
				<div class="col-lg-6 col-md-6 col-sm-12 col-12">
					<div class="nft-single-v2-img-full">
						<a href="<?php echo esc_url($nft_img_url);?>" alt="<?php echo the_title();?>" target="_blank">
							<?php echo NFT_Marketplace_Core\Internals\Helpers\Assets::getNFTDisplayAsset(get_the_ID()); ?>
						</a>
					</div>
				</div>
				<div class="col-lg-4 col-md-4 col-sm-12 col-12">
					<div class="collection-short-card">
						<?php if ($collection) { ?>
							<div class="collection-badge-v2">
								<a href="<?php echo esc_url(get_the_permalink());?>" class="nft-collection-image">
									<img src="<?php echo esc_url($collection_image_url); ?>" alt="<?php the_title(); ?>" />
								</a>
							</div>
						<?php } ?>
						<div class="blockchain-list">
							<span>Listed on: <strong><?php echo $blockchain_name;?></strong> blockchain</span>
						</div>
					</div>
					<div class="social-short-card">
						<div class="nft-social-info">
							<?php
							if ($collection) {
								?>
								<div class="nft-store-share">
									<?php
									do_action('nft_marketplace_core_single_nft_after_title_collection');
									?>
								</div>
								<?php
							}
							?>
							<h2 class="nft-content-title-v2"><?php echo the_title(); ?></h2>
						</div>
						<ul class="nft-social-list-v2">
							<li class="nft-social-list-v2-item">
								<span class="list-item-title"><?php echo esc_html__('Seller', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
								<div class="seller-group">
									<a href="<?php echo esc_url($author_link);?>" class="nft-author-image">
										<img src="<?php echo $author_avatar;?>" alt="<?php echo the_title();?>">
                                        <?php echo apply_filters("nft_marketplace_core_process_display_name", $auth_id); ?>
									</a>
								</div>
							</li>
							<li class="nft-social-list-v2-item">
								<span class="list-item-title"><?php echo esc_html__('Collection', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
								<div class="seller-group">
									<?php if ($collection) { ?>
										<a href="<?php echo esc_url(get_the_permalink()); ?>" class="nft-store-image">
											<img src="<?php echo esc_url($collection_image_url); ?>" alt="<?php the_title(); ?>" />
											<span><?php do_action('nft_marketplace_core_single_nft_after_title_collection'); ?></span>
										</a>
									<?php } else {
										echo esc_html__('Not in a collection', NFT_MARKETPLACE_CORE_TEXTDOMAIN);
									} ?>
								</div>
							</li>
						</ul>
					</div>
					<div class="nft-info-short-card">
						<?php
						if (!$listingStarted) {
							?>
							<h4><?php esc_html_e("Listing will start ", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . esc_html_e(wp_date('l, F jS, Y', $nft_marketplace_core_nft_listing_start_time)); ?></h4>
							<?php
						}
						?>
						<div class="info-buy-group">
							<div class="nft-buy-price">
								<?php
									if ($listingStarted && $isItemOnSale) {
										if ($customTokenAddress !== "0xeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeeee" && $customTokenAddress !== "") {
											echo '<div class="nft-price-symbol">' . Assets::getCurrencyImageSrcByTermId($currencyTermId, [18, 18]) . '</div>';
											echo '<p class="nft-price">' . esc_attr($price) . ' ' . esc_html($currencyTermMeta) . '</p>';
										} else {
											echo '<div class="nft-price-symbol">' . $nft_marketplace_blockchain_symbol . '</div>';
											echo '<p class="nft-price">' . esc_attr($price) . ' ' . esc_attr($additionalData["currency_symbol"]) . '</p>';
										}
									} else {
										echo '<p>' . esc_html_e("Listing will start ", NFT_MARKETPLACE_CORE_TEXTDOMAIN) . '</p>';
									}
								?>
							</div>
							<div class="nft-buy-btn-wrapper">
								<?php
								do_action('nft_marketplace_core_before_button', $isItemOnSale);
								if ($listingStarted && $isItemOnSale) {
									?>
									<form method="post" id="nft-marketplace-core-purchase-nft-form"
										<?php echo BlockchainDatasetBuilder::purchaseListing($nft_marketplace_core_nft_marketplace_id, $additionalData["marketplace_address"], $additionalData["term_id"]);?>
									>
										<button type="submit" name="nft_marketplace_core_buy_data" class="nft-single-v2-list-nft">
											<?php echo apply_filters('nft_marketplace_core_purchase_btn', esc_html__('Purchase Now', NFT_MARKETPLACE_CORE_TEXTDOMAIN)); ?>
										</button>
									</form>
									<?php
								} else if (get_current_user_id() === (int)$author) { ?>
									<a href="<?php echo add_query_arg(["list-nft" => true], get_permalink()) ?>">
										<button id="bid-btn" class="nft-buy-btn"><?php esc_html_e("List Now", NFT_MARKETPLACE_CORE_TEXTDOMAIN);?></button>
									</a>
									<?php
								}
								?>
							</div>
						</div>
						<div class="nft-info-short-group">
							<?php do_action('nft_marketplace_core_single_nft_before_title');?>
						</div>
					</div>
					<div class="nft-blockchain-info">
						<span><?php echo esc_html_e('This item is listed on the', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?> <strong><?php echo $blockchain_name;?></strong> <?php echo esc_html_e('blockchain.', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></span>
					</div>
				</div>
			</div>
			<div class="nft-description-row row">
				<div class="col-12">
					<div class="nft-description-card">
						<div class="row description-row">
							<div class="col-lg-7 col-md-7 col-sm-12 col-12 description-zone">
								<div class="description-zone-content">
									<h3 class="nft-description-title"><?php echo esc_html__('Description', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h3>
									<p class="description-content"><?php echo $nft_marketplace_core_nft_listing_description_meta; ?></p>
								</div>
							</div>
							<div class="col-lg-5 col-md-5 col-sm-12 col-12 seller-zone">
								<h3 class="nft-seller-title"><?php echo esc_html('Seller', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h3>
								<div class="seller-info-group">
									<div class="seller-info">
										<a href="<?php echo esc_url($author_link);?>" class="nft-seller-image">
											<img src="<?php echo $author_avatar;?>" alt="<?php echo the_title();?>">
										</a>
										<div class="seller-data">
											<a href="<?php echo esc_url($author_link);?>" class="seller-name">
                                                <?php echo apply_filters("nft_marketplace_core_process_display_name", $auth_id); ?>
                                            </a>
											<a href="<?php echo esc_url($author_link);?>" class="seller-address">@<?php echo the_author_meta("user_nicename", $auth_id); ?></a>
										</div>
									</div>
									<div class="count-group">
<!--										<div class="count-card-wrapper">-->
<!--											<div class="nft-count-card first-card">-->
<!--												<div class="nft-count-title"><i class="fas fa-boxes"></i></div>-->
<!--												<div class="nft-counts">--><?php //echo esc_html__("30", NFT_MARKETPLACE_CORE_TEXTDOMAIN);?><!--</div>-->
<!--											</div>-->
<!--											<div class="count-popup">-->
<!--												<span>--><?php //echo esc_html__("Items", NFT_MARKETPLACE_CORE_TEXTDOMAIN);?><!--</span>-->
<!--											</div>-->
<!--										</div>-->
										<div class="count-card-wrapper">
											<div class="nft-count-card first-card">
												<div class="nft-count-title"><i class="fas fa-box"></i></div>
												<div class="nft-counts"><?php echo $posts_count;?></div>
											</div>
											<div class="count-popup owned">
												<span><?php echo esc_html__("Owned NFTs", NFT_MARKETPLACE_CORE_TEXTDOMAIN);?></span>
											</div>
										</div>
										<div class="count-card-wrapper">
											<div class="nft-count-card last-card">
												<div class="nft-count-title"><i class="fas fa-eye"></i></div>
												<div class="nft-counts"><?php echo $views_count;?></div>
											</div>
											<div class="count-popup">
												<span><?php echo esc_html__("Views", NFT_MARKETPLACE_CORE_TEXTDOMAIN);?></span>
											</div>
										</div>
									</div>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="nft-metadata-section">
				<div class="nft-metadata-row">
					<div class="metadata-title-zone">
						<h3 class="nft-metadata-title"><?php echo esc_html__('Metadata', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></h3>
						<div class="metadata-btn-group">
							<?php
							// Add edit button for the author
							if (get_current_user_id() === (int)$author) {
								?>
								<a href="<?php echo add_query_arg(["edit-nft" => true], get_permalink()) ?>"
								   class="meta-btn"><?php esc_html_e("Edit", NFT_MARKETPLACE_CORE_TEXTDOMAIN) ?></a>
							<?php } ?>
							<button class="meta-tooltip accordion-btn" href="#"><i class="fas fa-sort-down"></i></button>
						</div>
					</div>
				</div>
				<div class="nft-metadata-content-row row" id="metadata-panel">
					<div class="metadata-content-col col-lg-4  col-md-4 col-sm-12 col-12">
						<div class="metadata-content-wrapper">
							<div class="metadata-content-title"><?php echo esc_html__('NFT Info', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></div>
							<div class="metadata-group">
								<div class="metadata-label"><?php echo esc_html__('Contract Address', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></div>
								<p class="metadata-info">
									<a href="#"><?php esc_html_e($nft_marketplace_core_nft_listing_address) ?></a>
								</p>
							</div>
							<div class="metadata-group">
								<div class="metadata-label"><?php echo esc_html__('Token ID', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></div>
								<button type="button" id="metadata-copy" class="metadata-token-btn">79034160960...7637<i class="fas fa-copy"></i></button>
							</div>
							<div class="metadata-group">
								<div class="metadata-label"><?php echo esc_html__('Token Name', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></div>
								<p class="metadata-info"><?php echo the_title(); ?></p>
							</div>
							<div class="metadata-group">
								<div class="metadata-label"><?php echo esc_html__('Original Image on NFT', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></div>
								<p class="metadata-info"><a href="<?php echo esc_url($nft_img_url);?>"><?php echo esc_html__('View Original Image', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></a> </p>
							</div>
						</div>
					</div>
<!--					<div class="metadata-content-col col-lg-4  col-md-4 col-sm-12 col-12">-->
<!--						<div class="metadata-content-wrapper">-->
<!--							<div class="metadata-content-title">--><?php //echo esc_html__('Royalties', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><!--</div>-->
<!--							<div class="metadata-group">-->
<!--								<div class="metadata-label">--><?php //echo esc_html__('Store Royalties', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><!--</div>-->
<!--								<p class="metadata-info">0%</p>-->
<!--							</div>-->
<!--							<div class="metadata-group">-->
<!--								<div class="metadata-label">--><?php //echo esc_html__('Onchain NFT royalty to creator', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><!--</div>-->
<!--								<p class="metadata-info">10%</p>-->
<!--							</div>-->
<!--							<div class="metadata-group">-->
<!--								<div class="metadata-label">--><?php //echo esc_html__('Mintable fee', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?><!-- </div>-->
<!--								<p class="metadata-info">2.5%</p>-->
<!--							</div>-->
<!--						</div>-->
<!--					</div>-->
					<div class="metadata-content-col col-lg-4  col-md-4 col-sm-12 col-12">
						<div class="metadata-content-wrapper metadata-json">
							<div class="metadata-content-copy">
								<button type="button" id="copy-meta-btn" class="metadata-copy-content"><?php echo esc_html__('Copy', NFT_MARKETPLACE_CORE_TEXTDOMAIN); ?></button>
							</div>
							<div class="metadata-json-content" id="json-text">
								{
								<div>
									<span>"name":</span><span>"<?php echo the_title();?>",</span>
								</div>
								<div>
									<span>"image":</span><span>"<?php echo $nft_img_url?>",</span>
								</div>
								<div>
									<span>"title":</span><span>"<?php echo the_title();?>",</span>
								</div>
								<div>
									<span>"address":</span><span>"<?php echo $nft_marketplace_core_nft_listing_address; ?>",</span>
								</div>
								<div>
									<span>"description":</span><span>"<?php echo $nft_marketplace_core_nft_listing_description_meta;?>",</span>
								</div>
								}
							</div>
						</div>
					</div>
				</div>
			</div>
			<div class="related-nft-section">
				<?php
				/**
				 * Hook: After Metas (Set Tabs Below)
				 */
				?>
				<?php if (isset(get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs']) && get_option('nft_marketplace_core_panel_single_nft')['nft_marketplace_core_tabs'] == 'bellow') { ?>
					<?php do_action('nft_marketplace_core_single_nft_before_related'); ?>
				<?php } ?>

				<?php
				/**
				 * Hook: Related NFT after content
				 */
				?>
				<?php do_action('nft_marketplace_core_single_nft_related'); ?>
			</div>
		</div>
	</main>
</div>
<?php
get_footer();
?>

